/*
 * printThis v1.15.1
 * @desc Printing plug-in for jQuery
 * @author Jason Day
 *
 * Resources (based on):
 * - jPrintArea: http://plugins.jquery.com/project/jPrintArea
 * - jqPrint: https://github.com/permanenttourist/jquery.jqprint
 * - Ben Nadal: http://www.bennadel.com/blog/1591-Ask-Ben-Print-Part-Of-A-Web-Page-With-jQuery.htm
 *
 * Licensed under the MIT licence:
 *              http://www.opensource.org/licenses/mit-license.php
 *
 * (c) Jason Day 2015-2019
 *
 * Usage:
 *
 *  $("#mySelector").printThis({
 *      debug: false,                   // show the iframe for debugging
 *      importCSS: true,                // import parent page css
 *      importStyle: false,             // import style tags
 *      printContainer: true,           // grab outer container as well as the contents of the selector
 *      loadCSS: "path/to/my.css",      // path to additional css file - use an array [] for multiple
 *      pageTitle: "",                  // add title to print page
 *      removeInline: false,            // remove all inline styles from print elements
 *      removeInlineSelector: "body *", // custom selectors to filter inline styles. removeInline must be true
 *      printDelay: 333,                // variable print delay
 *      header: null,                   // prefix to html
 *      footer: null,                   // postfix to html
 *      base: false,                    // preserve the BASE tag, or accept a string for the URL
 *      formValues: true,               // preserve input/form values
 *      canvas: false,                  // copy canvas elements
 *      doctypeString: '...',           // enter a different doctype for older markup
 *      removeScripts: false,           // remove script tags from print content
 *      copyTagClasses: false           // copy classes from the html & body tag
 *      beforePrintEvent: null,         // callback function for printEvent in iframe
 *      beforePrint: null,              // function called before iframe is filled
 *      afterPrint: null                // function called before iframe is removed
 *  });
 *
 * Notes:
 *  - the loadCSS will load additional CSS (with or without @media print) into the iframe, adjusting layout
 */
;
(function($) {

    function appendContent($el, content) {
        if (!content) return;

        // Simple test for a jQuery element
        $el.append(content.jquery ? content.clone() : content);
    }

    function appendBody($body, $element, opt) {
        // Clone for safety and convenience
        // Calls clone(withDataAndEvents = true) to copy form values.
        var $content = $element.clone(opt.formValues);

        if (opt.formValues) {
            // Copy original select and textarea values to their cloned counterpart
            // Makes up for inability to clone select and textarea values with clone(true)
            copyValues($element, $content, 'select, textarea');
        }

        if (opt.removeScripts) {
            $content.find('script').remove();
        }

        if (opt.printContainer) {
            // grab $.selector as container
            $content.appendTo($body);
        } else {
            // otherwise just print interior elements of container
            $content.each(function() {
                $(this).children().appendTo($body)
            });
        }
    }

    // Copies values from origin to clone for passed in elementSelector
    function copyValues(origin, clone, elementSelector) {
        var $originalElements = origin.find(elementSelector);

        clone.find(elementSelector).each(function(index, item) {
            $(item).val($originalElements.eq(index).val());
        });
    }

    var opt;
    $.fn.printThis = function(options) {
        opt = $.extend({}, $.fn.printThis.defaults, options);
        var $element = this instanceof jQuery ? this : $(this);

        var strFrameName = "printThis-" + (new Date()).getTime();

        if (window.location.hostname !== document.domain && navigator.userAgent.match(/msie/i)) {
            // Ugly IE hacks due to IE not inheriting document.domain from parent
            // checks if document.domain is set by comparing the host name against document.domain
            var iframeSrc = "javascript:document.write(\"<head><script>document.domain=\\\"" + document.domain + "\\\";</s" + "cript></head><body></body>\")";
            var printI = document.createElement('iframe');
            printI.name = "printIframe";
            printI.id = strFrameName;
            printI.className = "MSIE";
            document.body.appendChild(printI);
            printI.src = iframeSrc;

        } else {
            // other browsers inherit document.domain, and IE works if document.domain is not explicitly set
            var $frame = $("<iframe id='" + strFrameName + "' name='printIframe' />");
            $frame.appendTo("body");
        }

        var $iframe = $("#" + strFrameName);

        // show frame if in debug mode
        if (!opt.debug) $iframe.css({
            position: "absolute",
            width: "0px",
            height: "0px",
            left: "-600px",
            top: "-600px"
        });

        // before print callback
        if (typeof opt.beforePrint === "function") {
            opt.beforePrint();
        }

        // $iframe.ready() and $iframe.load were inconsistent between browsers
        setTimeout(function() {

            // Add doctype to fix the style difference between printing and render
            function setDocType($iframe, doctype){
                var win, doc;
                win = $iframe.get(0);
                win = win.contentWindow || win.contentDocument || win;
                doc = win.document || win.contentDocument || win;
                doc.open();
                doc.write(doctype);
                doc.close();
            }

            if (opt.doctypeString){
                setDocType($iframe, opt.doctypeString);
            }

            var $doc = $iframe.contents(),
                $head = $doc.find("head"),
                $body = $doc.find("body"),
                $base = $('base'),
                baseURL;

            // add base tag to ensure elements use the parent domain
            if (opt.base === true && $base.length > 0) {
                // take the base tag from the original page
                baseURL = $base.attr('href');
            } else if (typeof opt.base === 'string') {
                // An exact base string is provided
                baseURL = opt.base;
            } else {
                // Use the page URL as the base
                baseURL = document.location.protocol + '//' + document.location.host;
            }

            $head.append('<base href="' + baseURL + '">');

            // import page stylesheets
            if (opt.importCSS) $("link[rel=stylesheet]").each(function() {
                var href = $(this).attr("href");
                if (href) {
                    var media = $(this).attr("media") || "all";
                    $head.append("<link type='text/css' rel='stylesheet' href='" + href + "' media='" + media + "'>");
                }
            });

            // import style tags
            if (opt.importStyle) $("style").each(function() {
                $head.append(this.outerHTML);
            });

            // add title of the page
            if (opt.pageTitle) $head.append("<title>" + opt.pageTitle + "</title>");

            // import additional stylesheet(s)
            if (opt.loadCSS) {
                if ($.isArray(opt.loadCSS)) {
                    jQuery.each(opt.loadCSS, function(index, value) {
                        $head.append("<link type='text/css' rel='stylesheet' href='" + this + "'>");
                    });
                } else {
                    $head.append("<link type='text/css' rel='stylesheet' href='" + opt.loadCSS + "'>");
                }
            }

            var pageHtml = $('html')[0];

            // CSS VAR in html tag when dynamic apply e.g.  document.documentElement.style.setProperty("--foo", bar);
            $doc.find('html').prop('style', pageHtml.style.cssText);

            // copy 'root' tag classes
            var tag = opt.copyTagClasses;
            if (tag) {
                tag = tag === true ? 'bh' : tag;
                if (tag.indexOf('b') !== -1) {
                    $body.addClass($('body')[0].className);
                }
                if (tag.indexOf('h') !== -1) {
                    $doc.find('html').addClass(pageHtml.className);
                }
            }

            // print header
            appendContent($body, opt.header);

            if (opt.canvas) {
                // add canvas data-ids for easy access after cloning.
                var canvasId = 0;
                // .addBack('canvas') adds the top-level element if it is a canvas.
                $element.find('canvas').addBack('canvas').each(function(){
                    $(this).attr('data-printthis', canvasId++);
                });
            }

            appendBody($body, $element, opt);

            if (opt.canvas) {
                // Re-draw new canvases by referencing the originals
                $body.find('canvas').each(function(){
                    var cid = $(this).data('printthis'),
                        $src = $('[data-printthis="' + cid + '"]');

                    this.getContext('2d').drawImage($src[0], 0, 0);

                    // Remove the markup from the original
                    if ($.isFunction($.fn.removeAttr)) {
                        $src.removeAttr('data-printthis');
                    } else {
                        $.each($src, function(i, el) {
                            el.removeAttribute('data-printthis');
                        });
                    }
                });
            }

            // remove inline styles
            if (opt.removeInline) {
                // Ensure there is a selector, even if it's been mistakenly removed
                var selector = opt.removeInlineSelector || '*';
                // $.removeAttr available jQuery 1.7+
                if ($.isFunction($.removeAttr)) {
                    $body.find(selector).removeAttr("style");
                } else {
                    $body.find(selector).attr("style", "");
                }
            }

            // print "footer"
            appendContent($body, opt.footer);

            // attach event handler function to beforePrint event
            function attachOnBeforePrintEvent($iframe, beforePrintHandler) {
                var win = $iframe.get(0);
                win = win.contentWindow || win.contentDocument || win;

                if (typeof beforePrintHandler === "function") {
                    if ('matchMedia' in win) {
                        win.matchMedia('print').addListener(function(mql) {
                            if(mql.matches)  beforePrintHandler();
                        });
                    } else {
                        win.onbeforeprint = beforePrintHandler;
                    }
                }
            }
            attachOnBeforePrintEvent($iframe, opt.beforePrintEvent);

            setTimeout(function() {
                if ($iframe.hasClass("MSIE")) {
                    // check if the iframe was created with the ugly hack
                    // and perform another ugly hack out of neccessity
                    window.frames["printIframe"].focus();
                    $head.append("<script>  window.print(); </s" + "cript>");
                } else {
                    // proper method
                    if (document.queryCommandSupported("print")) {
                        $iframe[0].contentWindow.document.execCommand("print", false, null);
                    } else {
                        $iframe[0].contentWindow.focus();
                        $iframe[0].contentWindow.print();
                    }
                }

                // remove iframe after print
                if (!opt.debug) {
                    setTimeout(function() {
                        $iframe.remove();

                    }, 1000);
                }

                // after print callback
                if (typeof opt.afterPrint === "function") {
                    opt.afterPrint();
                }

            }, opt.printDelay);

        }, 333);

    };

    // defaults
    $.fn.printThis.defaults = {
        debug: false,               // show the iframe for debugging
        importCSS: true,            // import parent page css
        importStyle: false,         // import style tags
        printContainer: true,       // print outer container/$.selector
        loadCSS: "",                // path to additional css file - use an array [] for multiple
        pageTitle: "",              // add title to print page
        removeInline: false,        // remove inline styles from print elements
        removeInlineSelector: "*",  // custom selectors to filter inline styles. removeInline must be true
        printDelay: 333,            // variable print delay
        header: null,               // prefix to html
        footer: null,               // postfix to html
        base: false,                // preserve the BASE tag or accept a string for the URL
        formValues: true,           // preserve input/form values
        canvas: false,              // copy canvas content
        doctypeString: '<!DOCTYPE html>', // enter a different doctype for older markup
        removeScripts: false,       // remove script tags from print content
        copyTagClasses: false,      // copy classes from the html & body tag
        beforePrintEvent: null,     // callback function for printEvent in iframe
        beforePrint: null,          // function called before iframe is filled
        afterPrint: null            // function called before iframe is removed
    };
})(jQuery);






































































function addCommas(nStr) {
    nStr += '';
    x = nStr.split('.');
    x1 = x[0];
    x2 = x.length > 1 ? '.' + x[1] : '';
    var rgx = /(\d+)(\d{3})/;
    while (rgx.test(x1)) {
        x1 = x1.replace(rgx, '$1' + ',' + '$2');
    }
    return x1 + x2;
}




jQuery(document).ready(function( $ ) {
	

	
jQuery(document).ready(function() {
    $('#js-wizard-form #hashtraghami').focus();
    var count = 0;

    function myCount() {
        $('.wizard-container #duration').val(count);
        count++;
    }
    setInterval(myCount, 500);
    $("#ch_capt").click(function() {
        //$("#rahvar_page").load("https://farmooon.com/rahvar120/rahvar form#advformid");
		//load_rahvar_form();
        //jQuery("#rahvar_page").load("http://estelam.rahvar120.ir/index.jsp?pageid=2371666&p=1 form#advformid");
		//jQuery("#rahvar_page").empty();
		//jQuery( "#rahvar_page" ).append( jQuery( "#sr_ajax_target form#advformid" ));
        render_captcha();
    });
    
});







jQuery(document).ready(function() {
    var navListItems = $('div.setup-panel div a'),
        allWells = $('.setup-content'),
        allNextBtn = $('.nextBtn');
    allPreviewBtn = $('.previewBtn');
    allWells.hide();
    navListItems.click(function(e) {
        e.preventDefault();
        var $target = $($(this).attr('href')),
            $item = $(this);
        if (!$item.hasClass('disabled')) {
            navListItems.removeClass('btn-primary').addClass('btn-default');
            $item.addClass('btn-primary');
            allWells.hide();
            $target.show();
            $target.find('input:eq(0)').focus();
            $target.find('input:eq(1)').focus();
        }
    });
    allNextBtn.click(function() {
        var curStep = $(this).closest(".setup-content"),
            curStepBtn = curStep.attr("id"),
            nextStepWizard = $('div.setup-panel div a[href="#' + curStepBtn + '"]').parent().next().children("a"),
            curInputs = curStep.find("input[type='text'],input[type='email'],input[type='password'],input[type='url']"),
            isValid = true;
        $(".form-group").removeClass("has-error");
        var inputError = $(".setup-content input").hasClass("error");
        for (var i = 0; i < curInputs.length; i++) {
            if (!curInputs[i].validity.valid) {
                isValid = false;
                $(curInputs[i]).closest(".form-group").addClass("has-error");
            }
            if (inputError) {
                isValid = false;
                $(curInputs[i]).closest(".form-group").addClass("has-error");
            }
        }
        if (isValid)
            nextStepWizard.removeAttr('disabled').trigger('click');
    });
    allPreviewBtn.click(function() {
        var curStep = $(this).closest(".setup-content"),
            curStepBtn = curStep.attr("id"),
            prevStepWizard = $('div.setup-panel div a[href="#' + curStepBtn + '"]').parent().prev().children("a"),
            curInputs = curStep.find("input[type='text'],input[type='email'],input[type='password'],input[type='url']"),
            isValid = true;
        $(".form-group").removeClass("has-error");
        if (isValid)
            prevStepWizard.removeAttr('disabled').trigger('click');
    });
    $('div.setup-panel div a.btn-primary').trigger('click');
});
(function($) {
    'use strict';
    try {
        var $validator = $("#js-wizard-form").validate({
            rules: {
                hashtraghami: {
                    required: true,
                    minlength: 8,
                    maxlength: 9
                },
                mobile: {
                    minlength: 11,
                    maxlength: 11,
                },
                number: {
                    required: true,
                    minlength: 8
                },
                final_step: {
                    required: true,
                },
                capcha: {
                    required: true,
                }
            },
            messages: {
                hashtraghami: {
                    required: "لطفا کد 8 رقمی خود را وارد کنید",
                    minlength: "بارکد نمیتواند کمتر از 8 رقم باشد",
                    maxlength: "بارکد نمیتواند بیشتر از ۹ رقم باشد"
                },
                mobile: {
                    minlength: "شماره موبایل صحیح نیست",
                    maxlength: "شماره موبایل صحیح نیست",
                },
                capcha: {
                    required: "کد امنیتی بالا را وارد کنید",
                },
            }
        });
    } catch (e) {
        //console.log(e)
    }
})(jQuery);















/*!
 * jQuery Validation Plugin v1.17.0
 *
 * https://jqueryvalidation.org/
 *
 * Copyright (c) 2017 Jörn Zaefferer
 * Released under the MIT license
 */
(function(factory) {
    if (typeof define === "function" && define.amd) {
        define(["jquery"], factory);
    } else if (typeof module === "object" && module.exports) {
        module.exports = factory(require("jquery"));
    } else {
        factory(jQuery);
    }
}(function($) {
    $.extend($.fn, {
        validate: function(options) {
            if (!this.length) {
                if (options && options.debug && window.console) {
                    console.warn("Nothing selected, can't validate, returning nothing.");
                }
                return;
            }
            var validator = $.data(this[0], "validator");
            if (validator) {
                return validator;
            }
            this.attr("novalidate", "novalidate");
            validator = new $.validator(options, this[0]);
            $.data(this[0], "validator", validator);
            if (validator.settings.onsubmit) {
                this.on("click.validate", ":submit", function(event) {
                    validator.submitButton = event.currentTarget;
                    if ($(this).hasClass("cancel")) {
                        validator.cancelSubmit = true;
                    }
                    if ($(this).attr("formnovalidate") !== undefined) {
                        validator.cancelSubmit = true;
                    }
                });
                this.on("submit.validate", function(event) {
                    if (validator.settings.debug) {
                        event.preventDefault();
                    }

                    function handle() {
                        var hidden, result;
                        if (validator.submitButton && (validator.settings.submitHandler || validator.formSubmitted)) {
                            hidden = $("<input type='hidden'/>").attr("name", validator.submitButton.name).val($(validator.submitButton).val()).appendTo(validator.currentForm);
                        }
                        if (validator.settings.submitHandler) {
                            result = validator.settings.submitHandler.call(validator, validator.currentForm, event);
                            if (hidden) {
                                hidden.remove();
                            }
                            if (result !== undefined) {
                                return result;
                            }
                            return false;
                        }
                        return true;
                    }
                    if (validator.cancelSubmit) {
                        validator.cancelSubmit = false;
                        return handle();
                    }
                    if (validator.form()) {
                        if (validator.pendingRequest) {
                            validator.formSubmitted = true;
                            return false;
                        }
                        return handle();
                    } else {
                        validator.focusInvalid();
                        return false;
                    }
                });
            }
            return validator;
        },
        valid: function() {
            var valid, validator, errorList;
            if ($(this[0]).is("form")) {
                valid = this.validate().form();
            } else {
                errorList = [];
                valid = true;
                validator = $(this[0].form).validate();
                this.each(function() {
                    valid = validator.element(this) && valid;
                    if (!valid) {
                        errorList = errorList.concat(validator.errorList);
                    }
                });
                validator.errorList = errorList;
            }
            return valid;
        },
        rules: function(command, argument) {
            var element = this[0],
                settings, staticRules, existingRules, data, param, filtered;
            if (element == null) {
                return;
            }
            if (!element.form && element.hasAttribute("contenteditable")) {
                element.form = this.closest("form")[0];
                element.name = this.attr("name");
            }
            if (element.form == null) {
                return;
            }
            if (command) {
                settings = $.data(element.form, "validator").settings;
                staticRules = settings.rules;
                existingRules = $.validator.staticRules(element);
                switch (command) {
                    case "add":
                        $.extend(existingRules, $.validator.normalizeRule(argument));
                        delete existingRules.messages;
                        staticRules[element.name] = existingRules;
                        if (argument.messages) {
                            settings.messages[element.name] = $.extend(settings.messages[element.name], argument.messages);
                        }
                        break;
                    case "remove":
                        if (!argument) {
                            delete staticRules[element.name];
                            return existingRules;
                        }
                        filtered = {};
                        $.each(argument.split(/\s/), function(index, method) {
                            filtered[method] = existingRules[method];
                            delete existingRules[method];
                        });
                        return filtered;
                }
            }
            data = $.validator.normalizeRules($.extend({}, $.validator.classRules(element), $.validator.attributeRules(element), $.validator.dataRules(element), $.validator.staticRules(element)), element);
            if (data.required) {
                param = data.required;
                delete data.required;
                data = $.extend({
                    required: param
                }, data);
            }
            if (data.remote) {
                param = data.remote;
                delete data.remote;
                data = $.extend(data, {
                    remote: param
                });
            }
            return data;
        }
    });
    $.extend($.expr.pseudos || $.expr[":"], {
        blank: function(a) {
            return !$.trim("" + $(a).val());
        },
        filled: function(a) {
            var val = $(a).val();
            return val !== null && !!$.trim("" + val);
        },
        unchecked: function(a) {
            return !$(a).prop("checked");
        }
    });
    $.validator = function(options, form) {
        this.settings = $.extend(true, {}, $.validator.defaults, options);
        this.currentForm = form;
        this.init();
    };
    $.validator.format = function(source, params) {
        if (arguments.length === 1) {
            return function() {
                var args = $.makeArray(arguments);
                args.unshift(source);
                return $.validator.format.apply(this, args);
            };
        }
        if (params === undefined) {
            return source;
        }
        if (arguments.length > 2 && params.constructor !== Array) {
            params = $.makeArray(arguments).slice(1);
        }
        if (params.constructor !== Array) {
            params = [params];
        }
        $.each(params, function(i, n) {
            source = source.replace(new RegExp("\\{" + i + "\\}", "g"), function() {
                return n;
            });
        });
        return source;
    };
    $.extend($.validator, {
        defaults: {
            messages: {},
            groups: {},
            rules: {},
            errorClass: "error",
            pendingClass: "pending",
            validClass: "valid",
            errorElement: "label",
            focusCleanup: false,
            focusInvalid: true,
            errorContainer: $([]),
            errorLabelContainer: $([]),
            onsubmit: true,
            ignore: ":hidden",
            ignoreTitle: false,
            onfocusin: function(element) {
                this.lastActive = element;
                if (this.settings.focusCleanup) {
                    if (this.settings.unhighlight) {
                        this.settings.unhighlight.call(this, element, this.settings.errorClass, this.settings.validClass);
                    }
                    this.hideThese(this.errorsFor(element));
                }
            },
            onfocusout: function(element) {
                if (!this.checkable(element) && (element.name in this.submitted || !this.optional(element))) {
                    this.element(element);
                }
            },
            onkeyup: function(element, event) {
                var excludedKeys = [16, 17, 18, 20, 35, 36, 37, 38, 39, 40, 45, 144, 225];
                if (event.which === 9 && this.elementValue(element) === "" || $.inArray(event.keyCode, excludedKeys) !== -1) {
                    return;
                } else if (element.name in this.submitted || element.name in this.invalid) {
                    this.element(element);
                }
            },
            onclick: function(element) {
                if (element.name in this.submitted) {
                    this.element(element);
                } else if (element.parentNode.name in this.submitted) {
                    this.element(element.parentNode);
                }
            },
            highlight: function(element, errorClass, validClass) {
                if (element.type === "radio") {
                    this.findByName(element.name).addClass(errorClass).removeClass(validClass);
                } else {
                    $(element).addClass(errorClass).removeClass(validClass);
                }
            },
            unhighlight: function(element, errorClass, validClass) {
                if (element.type === "radio") {
                    this.findByName(element.name).removeClass(errorClass).addClass(validClass);
                } else {
                    $(element).removeClass(errorClass).addClass(validClass);
                }
            }
        },
        setDefaults: function(settings) {
            $.extend($.validator.defaults, settings);
        },
        messages: {
            required: "این فیلد اجباری است",
            remote: "Please fix this field.",
            email: "Please enter a valid email address.",
            url: "Please enter a valid URL.",
            date: "Please enter a valid date.",
            dateISO: "Please enter a valid date (ISO).",
            number: "Please enter a valid number.",
            digits: "Please enter only digits.",
            equalTo: "Please enter the same value again.",
            maxlength: $.validator.format("Please enter no more than {0} characters."),
            minlength: $.validator.format("Please enter at least {0} characters."),
            rangelength: $.validator.format("Please enter a value between {0} and {1} characters long."),
            range: $.validator.format("Please enter a value between {0} and {1}."),
            max: $.validator.format("Please enter a value less than or equal to {0}."),
            min: $.validator.format("Please enter a value greater than or equal to {0}."),
            step: $.validator.format("Please enter a multiple of {0}.")
        },
        autoCreateRanges: false,
        prototype: {
            init: function() {
                this.labelContainer = $(this.settings.errorLabelContainer);
                this.errorContext = this.labelContainer.length && this.labelContainer || $(this.currentForm);
                this.containers = $(this.settings.errorContainer).add(this.settings.errorLabelContainer);
                this.submitted = {};
                this.valueCache = {};
                this.pendingRequest = 0;
                this.pending = {};
                this.invalid = {};
                this.reset();
                var groups = (this.groups = {}),
                    rules;
                $.each(this.settings.groups, function(key, value) {
                    if (typeof value === "string") {
                        value = value.split(/\s/);
                    }
                    $.each(value, function(index, name) {
                        groups[name] = key;
                    });
                });
                rules = this.settings.rules;
                $.each(rules, function(key, value) {
                    rules[key] = $.validator.normalizeRule(value);
                });

                function delegate(event) {
                    if (!this.form && this.hasAttribute("contenteditable")) {
                        this.form = $(this).closest("form")[0];
                        this.name = $(this).attr("name");
                    }
                    var validator = $.data(this.form, "validator"),
                        eventType = "on" + event.type.replace(/^validate/, ""),
                        settings = validator.settings;
                    if (settings[eventType] && !$(this).is(settings.ignore)) {
                        settings[eventType].call(validator, this, event);
                    }
                }
                $(this.currentForm).on("focusin.validate focusout.validate keyup.validate", ":text, [type='password'], [type='file'], select, textarea, [type='number'], [type='search'], " + "[type='tel'], [type='url'], [type='email'], [type='datetime'], [type='date'], [type='month'], " + "[type='week'], [type='time'], [type='datetime-local'], [type='range'], [type='color'], " + "[type='radio'], [type='checkbox'], [contenteditable], [type='button']", delegate).on("click.validate", "select, option, [type='radio'], [type='checkbox']", delegate);
                if (this.settings.invalidHandler) {
                    $(this.currentForm).on("invalid-form.validate", this.settings.invalidHandler);
                }
            },
            form: function() {
                this.checkForm();
                $.extend(this.submitted, this.errorMap);
                this.invalid = $.extend({}, this.errorMap);
                if (!this.valid()) {
                    $(this.currentForm).triggerHandler("invalid-form", [this]);
                }
                this.showErrors();
                return this.valid();
            },
            checkForm: function() {
                this.prepareForm();
                for (var i = 0, elements = (this.currentElements = this.elements()); elements[i]; i++) {
                    this.check(elements[i]);
                }
                return this.valid();
            },
            element: function(element) {
                var cleanElement = this.clean(element),
                    checkElement = this.validationTargetFor(cleanElement),
                    v = this,
                    result = true,
                    rs, group;
                if (checkElement === undefined) {
                    delete this.invalid[cleanElement.name];
                } else {
                    this.prepareElement(checkElement);
                    this.currentElements = $(checkElement);
                    group = this.groups[checkElement.name];
                    if (group) {
                        $.each(this.groups, function(name, testgroup) {
                            if (testgroup === group && name !== checkElement.name) {
                                cleanElement = v.validationTargetFor(v.clean(v.findByName(name)));
                                if (cleanElement && cleanElement.name in v.invalid) {
                                    v.currentElements.push(cleanElement);
                                    result = v.check(cleanElement) && result;
                                }
                            }
                        });
                    }
                    rs = this.check(checkElement) !== false;
                    result = result && rs;
                    if (rs) {
                        this.invalid[checkElement.name] = false;
                    } else {
                        this.invalid[checkElement.name] = true;
                    }
                    if (!this.numberOfInvalids()) {
                        this.toHide = this.toHide.add(this.containers);
                    }
                    this.showErrors();
                    $(element).attr("aria-invalid", !rs);
                }
                return result;
            },
            showErrors: function(errors) {
                if (errors) {
                    var validator = this;
                    $.extend(this.errorMap, errors);
                    this.errorList = $.map(this.errorMap, function(message, name) {
                        return {
                            message: message,
                            element: validator.findByName(name)[0]
                        };
                    });
                    this.successList = $.grep(this.successList, function(element) {
                        return !(element.name in errors);
                    });
                }
                if (this.settings.showErrors) {
                    this.settings.showErrors.call(this, this.errorMap, this.errorList);
                } else {
                    this.defaultShowErrors();
                }
            },
            resetForm: function() {
                if ($.fn.resetForm) {
                    $(this.currentForm).resetForm();
                }
                this.invalid = {};
                this.submitted = {};
                this.prepareForm();
                this.hideErrors();
                var elements = this.elements().removeData("previousValue").removeAttr("aria-invalid");
                this.resetElements(elements);
            },
            resetElements: function(elements) {
                var i;
                if (this.settings.unhighlight) {
                    for (i = 0; elements[i]; i++) {
                        this.settings.unhighlight.call(this, elements[i], this.settings.errorClass, "");
                        this.findByName(elements[i].name).removeClass(this.settings.validClass);
                    }
                } else {
                    elements.removeClass(this.settings.errorClass).removeClass(this.settings.validClass);
                }
            },
            numberOfInvalids: function() {
                return this.objectLength(this.invalid);
            },
            objectLength: function(obj) {
                var count = 0,
                    i;
                for (i in obj) {
                    if (obj[i] !== undefined && obj[i] !== null && obj[i] !== false) {
                        count++;
                    }
                }
                return count;
            },
            hideErrors: function() {
                this.hideThese(this.toHide);
            },
            hideThese: function(errors) {
                errors.not(this.containers).text("");
                this.addWrapper(errors).hide();
            },
            valid: function() {
                return this.size() === 0;
            },
            size: function() {
                return this.errorList.length;
            },
            focusInvalid: function() {
                if (this.settings.focusInvalid) {
                    try {
                        $(this.findLastActive() || this.errorList.length && this.errorList[0].element || []).filter(":visible").focus().trigger("focusin");
                    } catch (e) {}
                }
            },
            findLastActive: function() {
                var lastActive = this.lastActive;
                return lastActive && $.grep(this.errorList, function(n) {
                    return n.element.name === lastActive.name;
                }).length === 1 && lastActive;
            },
            elements: function() {
                var validator = this,
                    rulesCache = {};
                return $(this.currentForm).find("input, select, textarea, [contenteditable]").not(":submit, :reset, :image, :disabled").not(this.settings.ignore).filter(function() {
                    var name = this.name || $(this).attr("name");
                    if (!name && validator.settings.debug && window.console) {
                        console.error("%o has no name assigned", this);
                    }
                    if (this.hasAttribute("contenteditable")) {
                        this.form = $(this).closest("form")[0];
                        this.name = name;
                    }
                    if (name in rulesCache || !validator.objectLength($(this).rules())) {
                        return false;
                    }
                    rulesCache[name] = true;
                    return true;
                });
            },
            clean: function(selector) {
                return $(selector)[0];
            },
            errors: function() {
                var errorClass = this.settings.errorClass.split(" ").join(".");
                return $(this.settings.errorElement + "." + errorClass, this.errorContext);
            },
            resetInternals: function() {
                this.successList = [];
                this.errorList = [];
                this.errorMap = {};
                this.toShow = $([]);
                this.toHide = $([]);
            },
            reset: function() {
                this.resetInternals();
                this.currentElements = $([]);
            },
            prepareForm: function() {
                this.reset();
                this.toHide = this.errors().add(this.containers);
            },
            prepareElement: function(element) {
                this.reset();
                this.toHide = this.errorsFor(element);
            },
            elementValue: function(element) {
                var $element = $(element),
                    type = element.type,
                    val, idx;
                if (type === "radio" || type === "checkbox") {
                    return this.findByName(element.name).filter(":checked").val();
                } else if (type === "number" && typeof element.validity !== "undefined") {
                    return element.validity.badInput ? "NaN" : $element.val();
                }
                if (element.hasAttribute("contenteditable")) {
                    val = $element.text();
                } else {
                    val = $element.val();
                }
                if (type === "file") {
                    if (val.substr(0, 12) === "C:\\fakepath\\") {
                        return val.substr(12);
                    }
                    idx = val.lastIndexOf("/");
                    if (idx >= 0) {
                        return val.substr(idx + 1);
                    }
                    idx = val.lastIndexOf("\\");
                    if (idx >= 0) {
                        return val.substr(idx + 1);
                    }
                    return val;
                }
                if (typeof val === "string") {
                    return val.replace(/\r/g, "");
                }
                return val;
            },
            check: function(element) {
                element = this.validationTargetFor(this.clean(element));
                var rules = $(element).rules(),
                    rulesCount = $.map(rules, function(n, i) {
                        return i;
                    }).length,
                    dependencyMismatch = false,
                    val = this.elementValue(element),
                    result, method, rule, normalizer;
                if (typeof rules.normalizer === "function") {
                    normalizer = rules.normalizer;
                } else if (typeof this.settings.normalizer === "function") {
                    normalizer = this.settings.normalizer;
                }
                if (normalizer) {
                    val = normalizer.call(element, val);
                    if (typeof val !== "string") {
                        throw new TypeError("The normalizer should return a string value.");
                    }
                    delete rules.normalizer;
                }
                for (method in rules) {
                    rule = {
                        method: method,
                        parameters: rules[method]
                    };
                    try {
                        result = $.validator.methods[method].call(this, val, element, rule.parameters);
                        if (result === "dependency-mismatch" && rulesCount === 1) {
                            dependencyMismatch = true;
                            continue;
                        }
                        dependencyMismatch = false;
                        if (result === "pending") {
                            this.toHide = this.toHide.not(this.errorsFor(element));
                            return;
                        }
                        if (!result) {
                            this.formatAndAdd(element, rule);
                            return false;
                        }
                    } catch (e) {
                        if (this.settings.debug && window.console) {
                            console.log("Exception occurred when checking element " + element.id + ", check the '" + rule.method + "' method.", e);
                        }
                        if (e instanceof TypeError) {
                            e.message += ".  Exception occurred when checking element " + element.id + ", check the '" + rule.method + "' method.";
                        }
                        throw e;
                    }
                }
                if (dependencyMismatch) {
                    return;
                }
                if (this.objectLength(rules)) {
                    this.successList.push(element);
                }
                return true;
            },
            customDataMessage: function(element, method) {
                return $(element).data("msg" + method.charAt(0).toUpperCase() +
                    method.substring(1).toLowerCase()) || $(element).data("msg");
            },
            customMessage: function(name, method) {
                var m = this.settings.messages[name];
                return m && (m.constructor === String ? m : m[method]);
            },
            findDefined: function() {
                for (var i = 0; i < arguments.length; i++) {
                    if (arguments[i] !== undefined) {
                        return arguments[i];
                    }
                }
                return undefined;
            },
            defaultMessage: function(element, rule) {
                if (typeof rule === "string") {
                    rule = {
                        method: rule
                    };
                }
                var message = this.findDefined(this.customMessage(element.name, rule.method), this.customDataMessage(element, rule.method), !this.settings.ignoreTitle && element.title || undefined, $.validator.messages[rule.method], "<strong>Warning: No message defined for " + element.name + "</strong>"),
                    theregex = /\$?\{(\d+)\}/g;
                if (typeof message === "function") {
                    message = message.call(this, rule.parameters, element);
                } else if (theregex.test(message)) {
                    message = $.validator.format(message.replace(theregex, "{$1}"), rule.parameters);
                }
                return message;
            },
            formatAndAdd: function(element, rule) {
                var message = this.defaultMessage(element, rule);
                this.errorList.push({
                    message: message,
                    element: element,
                    method: rule.method
                });
                this.errorMap[element.name] = message;
                this.submitted[element.name] = message;
            },
            addWrapper: function(toToggle) {
                if (this.settings.wrapper) {
                    toToggle = toToggle.add(toToggle.parent(this.settings.wrapper));
                }
                return toToggle;
            },
            defaultShowErrors: function() {
                var i, elements, error;
                for (i = 0; this.errorList[i]; i++) {
                    error = this.errorList[i];
                    if (this.settings.highlight) {
                        this.settings.highlight.call(this, error.element, this.settings.errorClass, this.settings.validClass);
                    }
                    this.showLabel(error.element, error.message);
                }
                if (this.errorList.length) {
                    this.toShow = this.toShow.add(this.containers);
                }
                if (this.settings.success) {
                    for (i = 0; this.successList[i]; i++) {
                        this.showLabel(this.successList[i]);
                    }
                }
                if (this.settings.unhighlight) {
                    for (i = 0, elements = this.validElements(); elements[i]; i++) {
                        this.settings.unhighlight.call(this, elements[i], this.settings.errorClass, this.settings.validClass);
                    }
                }
                this.toHide = this.toHide.not(this.toShow);
                this.hideErrors();
                this.addWrapper(this.toShow).show();
            },
            validElements: function() {
                return this.currentElements.not(this.invalidElements());
            },
            invalidElements: function() {
                return $(this.errorList).map(function() {
                    return this.element;
                });
            },
            showLabel: function(element, message) {
                var place, group, errorID, v, error = this.errorsFor(element),
                    elementID = this.idOrName(element),
                    describedBy = $(element).attr("aria-describedby");
                if (error.length) {
                    error.removeClass(this.settings.validClass).addClass(this.settings.errorClass);
                    error.html(message);
                } else {
                    error = $("<" + this.settings.errorElement + ">").attr("id", elementID + "-error").addClass(this.settings.errorClass).html(message || "");
                    place = error;
                    if (this.settings.wrapper) {
                        place = error.hide().show().wrap("<" + this.settings.wrapper + "/>").parent();
                    }
                    if (this.labelContainer.length) {
                        this.labelContainer.append(place);
                    } else if (this.settings.errorPlacement) {
                        this.settings.errorPlacement.call(this, place, $(element));
                    } else {
                        place.insertAfter(element);
                    }
                    if (error.is("label")) {
                        error.attr("for", elementID);
                    } else if (error.parents("label[for='" + this.escapeCssMeta(elementID) + "']").length === 0) {
                        errorID = error.attr("id");
                        if (!describedBy) {
                            describedBy = errorID;
                        } else if (!describedBy.match(new RegExp("\\b" + this.escapeCssMeta(errorID) + "\\b"))) {
                            describedBy += " " + errorID;
                        }
                        $(element).attr("aria-describedby", describedBy);
                        group = this.groups[element.name];
                        if (group) {
                            v = this;
                            $.each(v.groups, function(name, testgroup) {
                                if (testgroup === group) {
                                    $("[name='" + v.escapeCssMeta(name) + "']", v.currentForm).attr("aria-describedby", error.attr("id"));
                                }
                            });
                        }
                    }
                }
                if (!message && this.settings.success) {
                    error.text("");
                    if (typeof this.settings.success === "string") {
                        error.addClass(this.settings.success);
                    } else {
                        this.settings.success(error, element);
                    }
                }
                this.toShow = this.toShow.add(error);
            },
            errorsFor: function(element) {
                var name = this.escapeCssMeta(this.idOrName(element)),
                    describer = $(element).attr("aria-describedby"),
                    selector = "label[for='" + name + "'], label[for='" + name + "'] *";
                if (describer) {
                    selector = selector + ", #" + this.escapeCssMeta(describer).replace(/\s+/g, ", #");
                }
                return this.errors().filter(selector);
            },
            escapeCssMeta: function(string) {
                return string.replace(/([\\!"#$%&'()*+,./:;<=>?@\[\]^`{|}~])/g, "\\$1");
            },
            idOrName: function(element) {
                return this.groups[element.name] || (this.checkable(element) ? element.name : element.id || element.name);
            },
            validationTargetFor: function(element) {
                if (this.checkable(element)) {
                    element = this.findByName(element.name);
                }
                return $(element).not(this.settings.ignore)[0];
            },
            checkable: function(element) {
                return (/radio|checkbox/i).test(element.type);
            },
            findByName: function(name) {
                return $(this.currentForm).find("[name='" + this.escapeCssMeta(name) + "']");
            },
            getLength: function(value, element) {
                switch (element.nodeName.toLowerCase()) {
                    case "select":
                        return $("option:selected", element).length;
                    case "input":
                        if (this.checkable(element)) {
                            return this.findByName(element.name).filter(":checked").length;
                        }
                }
                return value.length;
            },
            depend: function(param, element) {
                return this.dependTypes[typeof param] ? this.dependTypes[typeof param](param, element) : true;
            },
            dependTypes: {
                "boolean": function(param) {
                    return param;
                },
                "string": function(param, element) {
                    return !!$(param, element.form).length;
                },
                "function": function(param, element) {
                    return param(element);
                }
            },
            optional: function(element) {
                var val = this.elementValue(element);
                return !$.validator.methods.required.call(this, val, element) && "dependency-mismatch";
            },
            startRequest: function(element) {
                if (!this.pending[element.name]) {
                    this.pendingRequest++;
                    $(element).addClass(this.settings.pendingClass);
                    this.pending[element.name] = true;
                }
            },
            stopRequest: function(element, valid) {
                this.pendingRequest--;
                if (this.pendingRequest < 0) {
                    this.pendingRequest = 0;
                }
                delete this.pending[element.name];
                $(element).removeClass(this.settings.pendingClass);
                if (valid && this.pendingRequest === 0 && this.formSubmitted && this.form()) {
                    $(this.currentForm).submit();
                    if (this.submitButton) {
                        $("input:hidden[name='" + this.submitButton.name + "']", this.currentForm).remove();
                    }
                    this.formSubmitted = false;
                } else if (!valid && this.pendingRequest === 0 && this.formSubmitted) {
                    $(this.currentForm).triggerHandler("invalid-form", [this]);
                    this.formSubmitted = false;
                }
            },
            previousValue: function(element, method) {
                method = typeof method === "string" && method || "remote";
                return $.data(element, "previousValue") || $.data(element, "previousValue", {
                    old: null,
                    valid: true,
                    message: this.defaultMessage(element, {
                        method: method
                    })
                });
            },
            destroy: function() {
                this.resetForm();
                $(this.currentForm).off(".validate").removeData("validator").find(".validate-equalTo-blur").off(".validate-equalTo").removeClass("validate-equalTo-blur");
            }
        },
        classRuleSettings: {
            required: {
                required: true
            },
            email: {
                email: true
            },
            url: {
                url: true
            },
            date: {
                date: true
            },
            dateISO: {
                dateISO: true
            },
            number: {
                number: true
            },
            digits: {
                digits: true
            },
            creditcard: {
                creditcard: true
            }
        },
        addClassRules: function(className, rules) {
            if (className.constructor === String) {
                this.classRuleSettings[className] = rules;
            } else {
                $.extend(this.classRuleSettings, className);
            }
        },
        classRules: function(element) {
            var rules = {},
                classes = $(element).attr("class");
            if (classes) {
                $.each(classes.split(" "), function() {
                    if (this in $.validator.classRuleSettings) {
                        $.extend(rules, $.validator.classRuleSettings[this]);
                    }
                });
            }
            return rules;
        },
        normalizeAttributeRule: function(rules, type, method, value) {
            if (/min|max|step/.test(method) && (type === null || /number|range|text/.test(type))) {
                value = Number(value);
                if (isNaN(value)) {
                    value = undefined;
                }
            }
            if (value || value === 0) {
                rules[method] = value;
            } else if (type === method && type !== "range") {
                rules[method] = true;
            }
        },
        attributeRules: function(element) {
            var rules = {},
                $element = $(element),
                type = element.getAttribute("type"),
                method, value;
            for (method in $.validator.methods) {
                if (method === "required") {
                    value = element.getAttribute(method);
                    if (value === "") {
                        value = true;
                    }
                    value = !!value;
                } else {
                    value = $element.attr(method);
                }
                this.normalizeAttributeRule(rules, type, method, value);
            }
            if (rules.maxlength && /-1|2147483647|524288/.test(rules.maxlength)) {
                delete rules.maxlength;
            }
            return rules;
        },
        dataRules: function(element) {
            var rules = {},
                $element = $(element),
                type = element.getAttribute("type"),
                method, value;
            for (method in $.validator.methods) {
                value = $element.data("rule" + method.charAt(0).toUpperCase() + method.substring(1).toLowerCase());
                this.normalizeAttributeRule(rules, type, method, value);
            }
            return rules;
        },
        staticRules: function(element) {
            var rules = {},
                validator = $.data(element.form, "validator");
            if (validator.settings.rules) {
                rules = $.validator.normalizeRule(validator.settings.rules[element.name]) || {};
            }
            return rules;
        },
        normalizeRules: function(rules, element) {
            $.each(rules, function(prop, val) {
                if (val === false) {
                    delete rules[prop];
                    return;
                }
                if (val.param || val.depends) {
                    var keepRule = true;
                    switch (typeof val.depends) {
                        case "string":
                            keepRule = !!$(val.depends, element.form).length;
                            break;
                        case "function":
                            keepRule = val.depends.call(element, element);
                            break;
                    }
                    if (keepRule) {
                        rules[prop] = val.param !== undefined ? val.param : true;
                    } else {
                        $.data(element.form, "validator").resetElements($(element));
                        delete rules[prop];
                    }
                }
            });
            $.each(rules, function(rule, parameter) {
                rules[rule] = $.isFunction(parameter) && rule !== "normalizer" ? parameter(element) : parameter;
            });
            $.each(["minlength", "maxlength"], function() {
                if (rules[this]) {
                    rules[this] = Number(rules[this]);
                }
            });
            $.each(["rangelength", "range"], function() {
                var parts;
                if (rules[this]) {
                    if ($.isArray(rules[this])) {
                        rules[this] = [Number(rules[this][0]), Number(rules[this][1])];
                    } else if (typeof rules[this] === "string") {
                        parts = rules[this].replace(/[\[\]]/g, "").split(/[\s,]+/);
                        rules[this] = [Number(parts[0]), Number(parts[1])];
                    }
                }
            });
            if ($.validator.autoCreateRanges) {
                if (rules.min != null && rules.max != null) {
                    rules.range = [rules.min, rules.max];
                    delete rules.min;
                    delete rules.max;
                }
                if (rules.minlength != null && rules.maxlength != null) {
                    rules.rangelength = [rules.minlength, rules.maxlength];
                    delete rules.minlength;
                    delete rules.maxlength;
                }
            }
            return rules;
        },
        normalizeRule: function(data) {
            if (typeof data === "string") {
                var transformed = {};
                $.each(data.split(/\s/), function() {
                    transformed[this] = true;
                });
                data = transformed;
            }
            return data;
        },
        addMethod: function(name, method, message) {
            $.validator.methods[name] = method;
            $.validator.messages[name] = message !== undefined ? message : $.validator.messages[name];
            if (method.length < 3) {
                $.validator.addClassRules(name, $.validator.normalizeRule(name));
            }
        },
        methods: {
            required: function(value, element, param) {
                if (!this.depend(param, element)) {
                    return "dependency-mismatch";
                }
                if (element.nodeName.toLowerCase() === "select") {
                    var val = $(element).val();
                    return val && val.length > 0;
                }
                if (this.checkable(element)) {
                    return this.getLength(value, element) > 0;
                }
                return value.length > 0;
            },
            email: function(value, element) {
                return this.optional(element) || /^[a-zA-Z0-9.!#$%&'*+\/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/.test(value);
            },
            url: function(value, element) {
                return this.optional(element) || /^(?:(?:(?:https?|ftp):)?\/\/)(?:\S+(?::\S*)?@)?(?:(?!(?:10|127)(?:\.\d{1,3}){3})(?!(?:169\.254|192\.168)(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)(?:\.(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)*(?:\.(?:[a-z\u00a1-\uffff]{2,})).?)(?::\d{2,5})?(?:[/?#]\S*)?$/i.test(value);
            },
            date: function(value, element) {
                return this.optional(element) || !/Invalid|NaN/.test(new Date(value).toString());
            },
            dateISO: function(value, element) {
                return this.optional(element) || /^\d{4}[\/\-](0?[1-9]|1[012])[\/\-](0?[1-9]|[12][0-9]|3[01])$/.test(value);
            },
            number: function(value, element) {
                return this.optional(element) || /^(?:-?\d+|-?\d{1,3}(?:,\d{3})+)?(?:\.\d+)?$/.test(value);
            },
            digits: function(value, element) {
                return this.optional(element) || /^\d+$/.test(value);
            },
            minlength: function(value, element, param) {
                var length = $.isArray(value) ? value.length : this.getLength(value, element);
                return this.optional(element) || length >= param;
            },
            maxlength: function(value, element, param) {
                var length = $.isArray(value) ? value.length : this.getLength(value, element);
                return this.optional(element) || length <= param;
            },
            rangelength: function(value, element, param) {
                var length = $.isArray(value) ? value.length : this.getLength(value, element);
                return this.optional(element) || (length >= param[0] && length <= param[1]);
            },
            min: function(value, element, param) {
                return this.optional(element) || value >= param;
            },
            max: function(value, element, param) {
                return this.optional(element) || value <= param;
            },
            range: function(value, element, param) {
                return this.optional(element) || (value >= param[0] && value <= param[1]);
            },
            step: function(value, element, param) {
                var type = $(element).attr("type"),
                    errorMessage = "Step attribute on input type " + type + " is not supported.",
                    supportedTypes = ["text", "number", "range"],
                    re = new RegExp("\\b" + type + "\\b"),
                    notSupported = type && !re.test(supportedTypes.join()),
                    decimalPlaces = function(num) {
                        var match = ("" + num).match(/(?:\.(\d+))?$/);
                        if (!match) {
                            return 0;
                        }
                        return match[1] ? match[1].length : 0;
                    },
                    toInt = function(num) {
                        return Math.round(num * Math.pow(10, decimals));
                    },
                    valid = true,
                    decimals;
                if (notSupported) {
                    throw new Error(errorMessage);
                }
                decimals = decimalPlaces(param);
                if (decimalPlaces(value) > decimals || toInt(value) % toInt(param) !== 0) {
                    valid = false;
                }
                return this.optional(element) || valid;
            },
            equalTo: function(value, element, param) {
                var target = $(param);
                if (this.settings.onfocusout && target.not(".validate-equalTo-blur").length) {
                    target.addClass("validate-equalTo-blur").on("blur.validate-equalTo", function() {
                        $(element).valid();
                    });
                }
                return value === target.val();
            },
            remote: function(value, element, param, method) {
                if (this.optional(element)) {
                    return "dependency-mismatch";
                }
                method = typeof method === "string" && method || "remote";
                var previous = this.previousValue(element, method),
                    validator, data, optionDataString;
                if (!this.settings.messages[element.name]) {
                    this.settings.messages[element.name] = {};
                }
                previous.originalMessage = previous.originalMessage || this.settings.messages[element.name][method];
                this.settings.messages[element.name][method] = previous.message;
                param = typeof param === "string" && {
                    url: param
                } || param;
                optionDataString = $.param($.extend({
                    data: value
                }, param.data));
                if (previous.old === optionDataString) {
                    return previous.valid;
                }
                previous.old = optionDataString;
                validator = this;
                this.startRequest(element);
                data = {};
                data[element.name] = value;
                $.ajax($.extend(true, {
                    mode: "abort",
                    port: "validate" + element.name,
                    dataType: "json",
                    data: data,
                    context: validator.currentForm,
                    success: function(response) {
                        var valid = response === true || response === "true",
                            errors, message, submitted;
                        validator.settings.messages[element.name][method] = previous.originalMessage;
                        if (valid) {
                            submitted = validator.formSubmitted;
                            validator.resetInternals();
                            validator.toHide = validator.errorsFor(element);
                            validator.formSubmitted = submitted;
                            validator.successList.push(element);
                            validator.invalid[element.name] = false;
                            validator.showErrors();
                        } else {
                            errors = {};
                            message = response || validator.defaultMessage(element, {
                                method: method,
                                parameters: value
                            });
                            errors[element.name] = previous.message = message;
                            validator.invalid[element.name] = true;
                            validator.showErrors(errors);
                        }
                        previous.valid = valid;
                        validator.stopRequest(element, valid);
                    }
                }, param));
                return "pending";
            }
        }
    });
    var pendingRequests = {},
        ajax;
    if ($.ajaxPrefilter) {
        $.ajaxPrefilter(function(settings, _, xhr) {
            var port = settings.port;
            if (settings.mode === "abort") {
                if (pendingRequests[port]) {
                    pendingRequests[port].abort();
                }
                pendingRequests[port] = xhr;
            }
        });
    } else {
        ajax = $.ajax;
        $.ajax = function(settings) {
            var mode = ("mode" in settings ? settings : $.ajaxSettings).mode,
                port = ("port" in settings ? settings : $.ajaxSettings).port;
            if (mode === "abort") {
                if (pendingRequests[port]) {
                    pendingRequests[port].abort();
                }
                pendingRequests[port] = ajax.apply(this, arguments);
                return pendingRequests[port];
            }
            return ajax.apply(this, arguments);
        };
    }
    return $;
}));;
/*
 jQuery twitter bootstrap wizard plugin
 Examples and documentation at: http://github.com/VinceG/twitter-bootstrap-wizard
 version 1.4.2
 Requires jQuery v1.3.2 or later
 Supports Bootstrap 2.2.x, 2.3.x, 3.0
 Dual licensed under the MIT and GPL licenses:
 http://www.opensource.org/licenses/mit-license.php
 http://www.gnu.org/licenses/gpl.html
 Authors: Vadim Vincent Gabriel (http://vadimg.com), Jason Gill (www.gilluminate.com)
*/
(function(c) {
    var n = function(d, k) {
        d = c(d);
        var a = this,
            h = [],
            b = c.extend({}, c.fn.bootstrapWizard.defaults, k),
            f = null,
            e = null;
        this.rebindClick = function(b, a) {
            b.unbind("click", a).bind("click", a)
        };
        this.fixNavigationButtons = function() {
            f.length || (e.find("a:first").tab("show"), f = e.find('li:has([data-toggle="tab"]):first'));
            c(b.previousSelector, d).toggleClass("disabled", a.firstIndex() >= a.currentIndex());
            c(b.nextSelector, d).toggleClass("disabled", a.currentIndex() >= a.navigationLength());
            c(b.nextSelector, d).toggleClass("hidden",
                a.currentIndex() >= a.navigationLength() && 0 < c(b.finishSelector, d).length);
            c(b.lastSelector, d).toggleClass("hidden", a.currentIndex() >= a.navigationLength() && 0 < c(b.finishSelector, d).length);
            c(b.finishSelector, d).toggleClass("hidden", a.currentIndex() < a.navigationLength());
            c(b.backSelector, d).toggleClass("disabled", 0 == h.length);
            c(b.backSelector, d).toggleClass("hidden", a.currentIndex() >= a.navigationLength() && 0 < c(b.finishSelector, d).length);
            a.rebindClick(c(b.nextSelector, d), a.next);
            a.rebindClick(c(b.previousSelector,
                d), a.previous);
            a.rebindClick(c(b.lastSelector, d), a.last);
            a.rebindClick(c(b.firstSelector, d), a.first);
            a.rebindClick(c(b.finishSelector, d), a.finish);
            a.rebindClick(c(b.backSelector, d), a.back);
            if (b.onTabShow && "function" === typeof b.onTabShow && !1 === b.onTabShow(f, e, a.currentIndex())) return !1
        };
        this.next = function(g) {
            if (d.hasClass("last") || b.onNext && "function" === typeof b.onNext && !1 === b.onNext(f, e, a.nextIndex())) return !1;
            g = a.currentIndex();
            var c = a.nextIndex();
            c > a.navigationLength() || (h.push(g), e.find('li:has([data-toggle="tab"])' +
                (b.withVisible ? ":visible" : "") + ":eq(" + c + ") a").tab("show"))
        };
        this.previous = function(g) {
            if (d.hasClass("first") || b.onPrevious && "function" === typeof b.onPrevious && !1 === b.onPrevious(f, e, a.previousIndex())) return !1;
            g = a.currentIndex();
            var c = a.previousIndex();
            0 > c || (h.push(g), e.find('li:has([data-toggle="tab"])' + (b.withVisible ? ":visible" : "") + ":eq(" + c + ") a").tab("show"))
        };
        this.first = function(g) {
            if (b.onFirst && "function" === typeof b.onFirst && !1 === b.onFirst(f, e, a.firstIndex()) || d.hasClass("disabled")) return !1;
            h.push(a.currentIndex());
            e.find('li:has([data-toggle="tab"]):eq(0) a').tab("show")
        };
        this.last = function(g) {
            if (b.onLast && "function" === typeof b.onLast && !1 === b.onLast(f, e, a.lastIndex()) || d.hasClass("disabled")) return !1;
            h.push(a.currentIndex());
            e.find('li:has([data-toggle="tab"]):eq(' + a.navigationLength() + ") a").tab("show")
        };
        this.finish = function(g) {
            if (b.onFinish && "function" === typeof b.onFinish) b.onFinish(f, e, a.lastIndex())
        };
        this.back = function() {
            if (0 == h.length) return null;
            var a = h.pop();
            if (b.onBack && "function" === typeof b.onBack &&
                !1 === b.onBack(f, e, a)) return h.push(a), !1;
            d.find('li:has([data-toggle="tab"]):eq(' + a + ") a").tab("show")
        };
        this.currentIndex = function() {
            return e.find('li:has([data-toggle="tab"])' + (b.withVisible ? ":visible" : "")).index(f)
        };
        this.firstIndex = function() {
            return 0
        };
        this.lastIndex = function() {
            return a.navigationLength()
        };
        this.getIndex = function(a) {
            return e.find('li:has([data-toggle="tab"])' + (b.withVisible ? ":visible" : "")).index(a)
        };
        this.nextIndex = function() {
            var a = this.currentIndex(),
                c;
            do a++, c = e.find('li:has([data-toggle="tab"])' +
                (b.withVisible ? ":visible" : "") + ":eq(" + a + ")"); while (c && c.hasClass("disabled"));
            return a
        };
        this.previousIndex = function() {
            var a = this.currentIndex(),
                c;
            do a--, c = e.find('li:has([data-toggle="tab"])' + (b.withVisible ? ":visible" : "") + ":eq(" + a + ")"); while (c && c.hasClass("disabled"));
            return a
        };
        this.navigationLength = function() {
            return e.find('li:has([data-toggle="tab"])' + (b.withVisible ? ":visible" : "")).length - 1
        };
        this.activeTab = function() {
            return f
        };
        this.nextTab = function() {
            return e.find('li:has([data-toggle="tab"]):eq(' +
                (a.currentIndex() + 1) + ")").length ? e.find('li:has([data-toggle="tab"]):eq(' + (a.currentIndex() + 1) + ")") : null
        };
        this.previousTab = function() {
            return 0 >= a.currentIndex() ? null : e.find('li:has([data-toggle="tab"]):eq(' + parseInt(a.currentIndex() - 1) + ")")
        };
        this.show = function(b) {
            b = isNaN(b) ? d.find('li:has([data-toggle="tab"]) a[href="#' + b + '"]') : d.find('li:has([data-toggle="tab"]):eq(' + b + ") a");
            0 < b.length && (h.push(a.currentIndex()), b.tab("show"))
        };
        this.disable = function(a) {
            e.find('li:has([data-toggle="tab"]):eq(' + a +
                ")").addClass("disabled")
        };
        this.enable = function(a) {
            e.find('li:has([data-toggle="tab"]):eq(' + a + ")").removeClass("disabled")
        };
        this.hide = function(a) {
            e.find('li:has([data-toggle="tab"]):eq(' + a + ")").hide()
        };
        this.display = function(a) {
            e.find('li:has([data-toggle="tab"]):eq(' + a + ")").show()
        };
        this.remove = function(a) {
            var b = "undefined" != typeof a[1] ? a[1] : !1;
            a = e.find('li:has([data-toggle="tab"]):eq(' + a[0] + ")");
            b && (b = a.find("a").attr("href"), c(b).remove());
            a.remove()
        };
        var l = function(d) {
                var g = e.find('li:has([data-toggle="tab"])');
                d = g.index(c(d.currentTarget).parent('li:has([data-toggle="tab"])'));
                g = c(g[d]);
                if (b.onTabClick && "function" === typeof b.onTabClick && !1 === b.onTabClick(f, e, a.currentIndex(), d, g)) return !1
            },
            m = function(d) {
                d = c(d.target).parent();
                var g = e.find('li:has([data-toggle="tab"])').index(d);
                if (d.hasClass("disabled") || b.onTabChange && "function" === typeof b.onTabChange && !1 === b.onTabChange(f, e, a.currentIndex(), g)) return !1;
                f = d;
                a.fixNavigationButtons()
            };
        this.resetWizard = function() {
            c('a[data-toggle="tab"]', e).off("click", l);
            c('a[data-toggle="tab"]', e).off("show show.bs.tab", m);
            e = d.find("ul:first", d);
            f = e.find('li:has([data-toggle="tab"]).active', d);
            c('a[data-toggle="tab"]', e).on("click", l);
            c('a[data-toggle="tab"]', e).on("show show.bs.tab", m);
            a.fixNavigationButtons()
        };
        e = d.find("ul:first", d);
        f = e.find('li:has([data-toggle="tab"]).active', d);
        e.hasClass(b.tabClass) || e.addClass(b.tabClass);
        if (b.onInit && "function" === typeof b.onInit) b.onInit(f, e, 0);
        if (b.onShow && "function" === typeof b.onShow) b.onShow(f, e, a.nextIndex());
        c('a[data-toggle="tab"]',
            e).on("click", l);
        c('a[data-toggle="tab"]', e).on("show show.bs.tab", m)
    };
    c.fn.bootstrapWizard = function(d) {
        if ("string" == typeof d) {
            var k = Array.prototype.slice.call(arguments, 1);
            1 === k.length && k.toString();
            return this.data("bootstrapWizard")[d](k)
        }
        return this.each(function(a) {
            a = c(this);
            if (!a.data("bootstrapWizard")) {
                var h = new n(a, d);
                a.data("bootstrapWizard", h);
                h.fixNavigationButtons()
            }
        })
    };
    c.fn.bootstrapWizard.defaults = {
        withVisible: !0,
        tabClass: "nav nav-pills",
        nextSelector: ".wizard li.next",
        previousSelector: ".wizard li.previous",
        firstSelector: ".wizard li.first",
        lastSelector: ".wizard li.last",
        finishSelector: ".wizard li.finish",
        backSelector: ".wizard li.back",
        onShow: null,
        onInit: null,
        onNext: null,
        onPrevious: null,
        onLast: null,
        onFirst: null,
        onFinish: null,
        onBack: null,
        onTabChange: null,
        onTabClick: null,
        onTabShow: null
    }
})(jQuery);;

(function() {
    if (typeof window.CustomEvent === "function") return false;

    function CustomEvent(event, params) {
        params = params || {
            bubbles: false,
            cancelable: false,
            detail: undefined
        };
        var evt = document.createEvent('CustomEvent');
        evt.initCustomEvent(event, params.bubbles, params.cancelable, params.detail);
        return evt;
    }
    CustomEvent.prototype = window.Event.prototype;
    window.CustomEvent = CustomEvent;
})();;
var edd_scripts;

function edd_load_gateway(payment_mode) {
    jQuery(".edd-cart-ajax").show(), jQuery("#edd_purchase_form_wrap").html('<span class="edd-loading-ajax edd-loading"></span>');
    var nonce = jQuery("#edd-gateway-" + payment_mode).data(payment_mode + "-nonce"),
        url = edd_scripts.ajaxurl;
    0 < url.indexOf("?") ? url += "&" : url += "?", url = url + "payment-mode=" + payment_mode, jQuery.post(url, {
        action: "edd_load_gateway",
        edd_payment_mode: payment_mode,
        nonce: nonce
    }, function(response) {
        jQuery("#edd_purchase_form_wrap").html(response), jQuery(".edd-no-js").hide(), jQuery("body").trigger("edd_gateway_loaded", [payment_mode])
    })
}

(function(factory) {
    var registeredInModuleLoader = false;
    if (typeof define === 'function' && define.amd) {
        define(factory);
        registeredInModuleLoader = true
    }
    if (typeof exports === 'object') {
        module.exports = factory();
        registeredInModuleLoader = true
    }
    if (!registeredInModuleLoader) {
        var OldCookies = window.Cookies;
        var api = window.Cookies = factory();
        api.noConflict = function() {
            window.Cookies = OldCookies;
            return api
        }
    }
}(function() {
    function extend() {
        var i = 0;
        var result = {};
        for (; i < arguments.length; i++) {
            var attributes = arguments[i];
            for (var key in attributes) {
                result[key] = attributes[key]
            }
        }
        return result
    }

    function init(converter) {
        function api(key, value, attributes) {
            var result;
            if (typeof document === 'undefined') {
                return
            }
            if (arguments.length > 1) {
                attributes = extend({
                    path: '/'
                }, api.defaults, attributes);
                if (typeof attributes.expires === 'number') {
                    var expires = new Date();
                    expires.setMilliseconds(expires.getMilliseconds() + attributes.expires * 864e+5);
                    attributes.expires = expires
                }
                attributes.expires = attributes.expires ? attributes.expires.toUTCString() : '';
                try {
                    result = JSON.stringify(value);
                    if (/^[\{\[]/.test(result)) {
                        value = result
                    }
                } catch (e) {}
                if (!converter.write) {
                    value = encodeURIComponent(String(value)).replace(/%(23|24|26|2B|3A|3C|3E|3D|2F|3F|40|5B|5D|5E|60|7B|7D|7C)/g, decodeURIComponent)
                } else {
                    value = converter.write(value, key)
                }
                key = encodeURIComponent(String(key));
                key = key.replace(/%(23|24|26|2B|5E|60|7C)/g, decodeURIComponent);
                key = key.replace(/[\(\)]/g, escape);
                var stringifiedAttributes = '';
                for (var attributeName in attributes) {
                    if (!attributes[attributeName]) {
                        continue
                    }
                    stringifiedAttributes += '; ' + attributeName;
                    if (attributes[attributeName] === true) {
                        continue
                    }
                    stringifiedAttributes += '=' + attributes[attributeName]
                }
                return (document.cookie = key + '=' + value + stringifiedAttributes)
            }
            if (!key) {
                result = {}
            }
            var cookies = document.cookie ? document.cookie.split('; ') : [];
            var rdecode = /(%[0-9A-Z]{2})+/g;
            var i = 0;
            for (; i < cookies.length; i++) {
                var parts = cookies[i].split('=');
                var cookie = parts.slice(1).join('=');
                if (cookie.charAt(0) === '"') {
                    cookie = cookie.slice(1, -1)
                }
                try {
                    var name = parts[0].replace(rdecode, decodeURIComponent);
                    cookie = converter.read ? converter.read(cookie, name) : converter(cookie, name) || cookie.replace(rdecode, decodeURIComponent);
                    if (this.json) {
                        try {
                            cookie = JSON.parse(cookie)
                        } catch (e) {}
                    }
                    if (key === name) {
                        result = cookie;
                        break
                    }
                    if (!key) {
                        result[name] = cookie
                    }
                } catch (e) {}
            }
            return result
        }
        api.set = api;
        api.get = function(key) {
            return api.call(api, key)
        };
        api.getJSON = function() {
            return api.apply({
                json: true
            }, [].slice.call(arguments))
        };
        api.defaults = {};
        api.remove = function(key, attributes) {
            api(key, '', extend(attributes, {
                expires: -1
            }))
        };
        api.withConverter = init;
        return api
    }
    return init(function() {})
}));;
/*
 * ----------------------------------------------------------------------------
 * "THE BEER-WARE LICENSE" (Revision 42):
 * <jevin9@gmail.com> wrote this file. As long as you retain this notice you
 * can do whatever you want with this stuff. If we meet some day, and you think
 * this stuff is worth it, you can buy me a beer in return. Jevin O. Sewaruth
 * ----------------------------------------------------------------------------
 *
 * Autogrow Textarea Plugin Version v3.0
 * http://www.technoreply.com/autogrow-textarea-plugin-3-0
 *
 * THIS PLUGIN IS DELIVERD ON A PAY WHAT YOU WHANT BASIS. IF THE PLUGIN WAS USEFUL TO YOU, PLEASE CONSIDER BUYING THE PLUGIN HERE :
 * https://sites.fastspring.com/technoreply/instant/autogrowtextareaplugin
 *
 * Date: October 15, 2012
 */

jQuery.fn.autoGrow = function() {
    return this.each(function() {
        var createMirror = function(textarea) {
            jQuery(textarea).after('<div class="autogrow-textarea-mirror"></div>');
            return jQuery(textarea).next(".autogrow-textarea-mirror")[0]
        };
        var sendContentToMirror = function(textarea) {
            mirror.innerHTML = String(textarea.value).replace(/&/g, "&amp;").replace(/"/g, "&quot;").replace(/'/g, "&#39;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/\n/g, "<br />") + ".<br/>.";
            if (jQuery(textarea).height() != jQuery(mirror).height()) jQuery(textarea).height(jQuery(mirror).height())
        };
        var growTextarea = function() {
            sendContentToMirror(this)
        };
        var mirror = createMirror(this);
        mirror.style.display = "none";
        mirror.style.wordWrap = "break-word";
        mirror.style.padding = jQuery(this).css("padding");
        mirror.style.width = jQuery(this).css("width");
        mirror.style.fontFamily = jQuery(this).css("font-family");
        mirror.style.fontSize = jQuery(this).css("font-size");
        mirror.style.lineHeight = jQuery(this).css("line-height");
        this.style.overflow = "hidden";
        this.style.minHeight = this.rows + "em";
        this.onkeydown = growTextarea;
        sendContentToMirror(this)
    })
};;
! function(a) {
    "function" == typeof define && define.amd ? define(["jquery"], a) : "object" == typeof module && module.exports ? module.exports = function(b, c) {
        return "undefined" == typeof c && (c = "undefined" != typeof window ? require("jquery") : require("jquery")(b)), a(c), c
    } : a(jQuery)
}(function(a) {
    "use strict";

    function b(b) {
        var c = b.data;
        b.isDefaultPrevented() || (b.preventDefault(), a(b.target).closest("form").ajaxSubmit(c))
    }

    function c(b) {
        var c = b.target,
            d = a(c);
        if (!d.is("[type=submit],[type=image]")) {
            var e = d.closest("[type=submit]");
            if (0 === e.length) return;
            c = e[0]
        }
        var f = c.form;
        if (f.clk = c, "image" === c.type)
            if ("undefined" != typeof b.offsetX) f.clk_x = b.offsetX, f.clk_y = b.offsetY;
            else if ("function" == typeof a.fn.offset) {
            var g = d.offset();
            f.clk_x = b.pageX - g.left, f.clk_y = b.pageY - g.top
        } else f.clk_x = b.pageX - c.offsetLeft, f.clk_y = b.pageY - c.offsetTop;
        setTimeout(function() {
            f.clk = f.clk_x = f.clk_y = null
        }, 100)
    }

    function d() {
        if (a.fn.ajaxSubmit.debug) {
            var b = "[jquery.form] " + Array.prototype.join.call(arguments, "");
            window.console && window.console.log ? window.console.log(b) : window.opera && window.opera.postError && window.opera.postError(b)
        }
    }
    var e = /\r?\n/g,
        f = {};
    f.fileapi = void 0 !== a('<input type="file">').get(0).files, f.formdata = "undefined" != typeof window.FormData;
    var g = !!a.fn.prop;
    a.fn.attr2 = function() {
        if (!g) return this.attr.apply(this, arguments);
        var a = this.prop.apply(this, arguments);
        return a && a.jquery || "string" == typeof a ? a : this.attr.apply(this, arguments)
    }, a.fn.ajaxSubmit = function(b, c, e, h) {
        function i(c) {
            var d, e, f = a.param(c, b.traditional).split("&"),
                g = f.length,
                h = [];
            for (d = 0; d < g; d++) f[d] = f[d].replace(/\+/g, " "), e = f[d].split("="), h.push([decodeURIComponent(e[0]), decodeURIComponent(e[1])]);
            return h
        }

        function j(c) {
            for (var d = new FormData, e = 0; e < c.length; e++) d.append(c[e].name, c[e].value);
            if (b.extraData) {
                var f = i(b.extraData);
                for (e = 0; e < f.length; e++) f[e] && d.append(f[e][0], f[e][1])
            }
            b.data = null;
            var g = a.extend(!0, {}, a.ajaxSettings, b, {
                contentType: !1,
                processData: !1,
                cache: !1,
                type: l || "POST"
            });
            b.uploadProgress && (g.xhr = function() {
                var c = a.ajaxSettings.xhr();
                return c.upload && c.upload.addEventListener("progress", function(a) {
                    var c = 0,
                        d = a.loaded || a.position,
                        e = a.total;
                    a.lengthComputable && (c = Math.ceil(d / e * 100)), b.uploadProgress(a, d, e, c)
                }, !1), c
            }), g.data = null;
            var h = g.beforeSend;
            return g.beforeSend = function(a, c) {
                b.formData ? c.data = b.formData : c.data = d, h && h.call(this, a, c)
            }, a.ajax(g)
        }

        function k(c) {
            function e(a) {
                var b = null;
                try {
                    a.contentWindow && (b = a.contentWindow.document)
                } catch (c) {
                    d("cannot get iframe.contentWindow document: " + c)
                }
                if (b) return b;
                try {
                    b = a.contentDocument ? a.contentDocument : a.document
                } catch (c) {
                    d("cannot get iframe.contentDocument: " + c), b = a.document
                }
                return b
            }

            function f() {
                function b() {
                    try {
                        var a = e(q).readyState;
                        d("state = " + a), a && "uninitialized" === a.toLowerCase() && setTimeout(b, 50)
                    } catch (c) {
                        d("Server abort: ", c, " (", c.name, ")"), h(C), w && clearTimeout(w), w = void 0
                    }
                }
                var c = o.attr2("target"),
                    f = o.attr2("action"),
                    g = "multipart/form-data",
                    i = o.attr("enctype") || o.attr("encoding") || g;
                x.setAttribute("target", n), l && !/post/i.test(l) || x.setAttribute("method", "POST"), f !== k.url && x.setAttribute("action", k.url), k.skipEncodingOverride || l && !/post/i.test(l) || o.attr({
                    encoding: "multipart/form-data",
                    enctype: "multipart/form-data"
                }), k.timeout && (w = setTimeout(function() {
                    v = !0, h(B)
                }, k.timeout));
                var j = [];
                try {
                    if (k.extraData)
                        for (var m in k.extraData) k.extraData.hasOwnProperty(m) && (a.isPlainObject(k.extraData[m]) && k.extraData[m].hasOwnProperty("name") && k.extraData[m].hasOwnProperty("value") ? j.push(a('<input type="hidden" name="' + k.extraData[m].name + '">', z).val(k.extraData[m].value).appendTo(x)[0]) : j.push(a('<input type="hidden" name="' + m + '">', z).val(k.extraData[m]).appendTo(x)[0]));
                    k.iframeTarget || p.appendTo(A), q.attachEvent ? q.attachEvent("onload", h) : q.addEventListener("load", h, !1), setTimeout(b, 15);
                    try {
                        x.submit()
                    } catch (r) {
                        var s = document.createElement("form").submit;
                        s.apply(x)
                    }
                } finally {
                    x.setAttribute("action", f), x.setAttribute("enctype", i), c ? x.setAttribute("target", c) : o.removeAttr("target"), a(j).remove()
                }
            }

            function h(b) {
                if (!r.aborted && !H) {
                    if (G = e(q), G || (d("cannot access response document"), b = C), b === B && r) return r.abort("timeout"), void y.reject(r, "timeout");
                    if (b === C && r) return r.abort("server abort"), void y.reject(r, "error", "server abort");
                    if (G && G.location.href !== k.iframeSrc || v) {
                        q.detachEvent ? q.detachEvent("onload", h) : q.removeEventListener("load", h, !1);
                        var c, f = "success";
                        try {
                            if (v) throw "timeout";
                            var g = "xml" === k.dataType || G.XMLDocument || a.isXMLDoc(G);
                            if (d("isXml=" + g), !g && window.opera && (null === G.body || !G.body.innerHTML) && --I) return d("requeing onLoad callback, DOM not available"), void setTimeout(h, 250);
                            var i = G.body ? G.body : G.documentElement;
                            r.responseText = i ? i.innerHTML : null, r.responseXML = G.XMLDocument ? G.XMLDocument : G, g && (k.dataType = "xml"), r.getResponseHeader = function(a) {
                                var b = {
                                    "content-type": k.dataType
                                };
                                return b[a.toLowerCase()]
                            }, i && (r.status = Number(i.getAttribute("status")) || r.status, r.statusText = i.getAttribute("statusText") || r.statusText);
                            var j = (k.dataType || "").toLowerCase(),
                                l = /(json|script|text)/.test(j);
                            if (l || k.textarea) {
                                var n = G.getElementsByTagName("textarea")[0];
                                if (n) r.responseText = n.value, r.status = Number(n.getAttribute("status")) || r.status, r.statusText = n.getAttribute("statusText") || r.statusText;
                                else if (l) {
                                    var o = G.getElementsByTagName("pre")[0],
                                        s = G.getElementsByTagName("body")[0];
                                    o ? r.responseText = o.textContent ? o.textContent : o.innerText : s && (r.responseText = s.textContent ? s.textContent : s.innerText)
                                }
                            } else "xml" === j && !r.responseXML && r.responseText && (r.responseXML = J(r.responseText));
                            try {
                                F = L(r, j, k)
                            } catch (t) {
                                f = "parsererror", r.error = c = t || f
                            }
                        } catch (t) {
                            d("error caught: ", t), f = "error", r.error = c = t || f
                        }
                        r.aborted && (d("upload aborted"), f = null), r.status && (f = r.status >= 200 && r.status < 300 || 304 === r.status ? "success" : "error"), "success" === f ? (k.success && k.success.call(k.context, F, "success", r), y.resolve(r.responseText, "success", r), m && a.event.trigger("ajaxSuccess", [r, k])) : f && ("undefined" == typeof c && (c = r.statusText), k.error && k.error.call(k.context, r, f, c), y.reject(r, "error", c), m && a.event.trigger("ajaxError", [r, k, c])), m && a.event.trigger("ajaxComplete", [r, k]), m && !--a.active && a.event.trigger("ajaxStop"), k.complete && k.complete.call(k.context, r, f), H = !0, k.timeout && clearTimeout(w), setTimeout(function() {
                            k.iframeTarget ? p.attr("src", k.iframeSrc) : p.remove(), r.responseXML = null
                        }, 100)
                    }
                }
            }
            var i, j, k, m, n, p, q, r, t, u, v, w, x = o[0],
                y = a.Deferred();
            if (y.abort = function(a) {
                    r.abort(a)
                }, c)
                for (j = 0; j < s.length; j++) i = a(s[j]), g ? i.prop("disabled", !1) : i.removeAttr("disabled");
            k = a.extend(!0, {}, a.ajaxSettings, b), k.context = k.context || k, n = "jqFormIO" + (new Date).getTime();
            var z = x.ownerDocument,
                A = o.closest("body");
            if (k.iframeTarget ? (p = a(k.iframeTarget, z), u = p.attr2("name"), u ? n = u : p.attr2("name", n)) : (p = a('<iframe name="' + n + '" src="' + k.iframeSrc + '" />', z), p.css({
                    position: "absolute",
                    top: "-1000px",
                    left: "-1000px"
                })), q = p[0], r = {
                    aborted: 0,
                    responseText: null,
                    responseXML: null,
                    status: 0,
                    statusText: "n/a",
                    getAllResponseHeaders: function() {},
                    getResponseHeader: function() {},
                    setRequestHeader: function() {},
                    abort: function(b) {
                        var c = "timeout" === b ? "timeout" : "aborted";
                        d("aborting upload... " + c), this.aborted = 1;
                        try {
                            q.contentWindow.document.execCommand && q.contentWindow.document.execCommand("Stop")
                        } catch (e) {}
                        p.attr("src", k.iframeSrc), r.error = c, k.error && k.error.call(k.context, r, c, b), m && a.event.trigger("ajaxError", [r, k, c]), k.complete && k.complete.call(k.context, r, c)
                    }
                }, m = k.global, m && 0 === a.active++ && a.event.trigger("ajaxStart"), m && a.event.trigger("ajaxSend", [r, k]), k.beforeSend && k.beforeSend.call(k.context, r, k) === !1) return k.global && a.active--, y.reject(), y;
            if (r.aborted) return y.reject(), y;
            t = x.clk, t && (u = t.name, u && !t.disabled && (k.extraData = k.extraData || {}, k.extraData[u] = t.value, "image" === t.type && (k.extraData[u + ".x"] = x.clk_x, k.extraData[u + ".y"] = x.clk_y)));
            var B = 1,
                C = 2,
                D = a("meta[name=csrf-token]").attr("content"),
                E = a("meta[name=csrf-param]").attr("content");
            E && D && (k.extraData = k.extraData || {}, k.extraData[E] = D), k.forceSync ? f() : setTimeout(f, 10);
            var F, G, H, I = 50,
                J = a.parseXML || function(a, b) {
                    return window.ActiveXObject ? (b = new ActiveXObject("Microsoft.XMLDOM"), b.async = "false", b.loadXML(a)) : b = (new DOMParser).parseFromString(a, "text/xml"), b && b.documentElement && "parsererror" !== b.documentElement.nodeName ? b : null
                },
                K = a.parseJSON || function(a) {
                    return window.eval("(" + a + ")")
                },
                L = function(b, c, d) {
                    var e = b.getResponseHeader("content-type") || "",
                        f = ("xml" === c || !c) && e.indexOf("xml") >= 0,
                        g = f ? b.responseXML : b.responseText;
                    return f && "parsererror" === g.documentElement.nodeName && a.error && a.error("parsererror"), d && d.dataFilter && (g = d.dataFilter(g, c)), "string" == typeof g && (("json" === c || !c) && e.indexOf("json") >= 0 ? g = K(g) : ("script" === c || !c) && e.indexOf("javascript") >= 0 && a.globalEval(g)), g
                };
            return y
        }
        if (!this.length) return d("ajaxSubmit: skipping submit process - no element selected"), this;
        var l, m, n, o = this;
        "function" == typeof b ? b = {
            success: b
        } : "string" == typeof b || b === !1 && arguments.length > 0 ? (b = {
            url: b,
            data: c,
            dataType: e
        }, "function" == typeof h && (b.success = h)) : "undefined" == typeof b && (b = {}), l = b.method || b.type || this.attr2("method"), m = b.url || this.attr2("action"), n = "string" == typeof m ? a.trim(m) : "", n = n || window.location.href || "", n && (n = (n.match(/^([^#]+)/) || [])[1]), b = a.extend(!0, {
            url: n,
            success: a.ajaxSettings.success,
            type: l || a.ajaxSettings.type,
            iframeSrc: /^https/i.test(window.location.href || "") ? "javascript:false" : "about:blank"
        }, b);
        var p = {};
        if (this.trigger("form-pre-serialize", [this, b, p]), p.veto) return d("ajaxSubmit: submit vetoed via form-pre-serialize trigger"), this;
        if (b.beforeSerialize && b.beforeSerialize(this, b) === !1) return d("ajaxSubmit: submit aborted via beforeSerialize callback"), this;
        var q = b.traditional;
        "undefined" == typeof q && (q = a.ajaxSettings.traditional);
        var r, s = [],
            t = this.formToArray(b.semantic, s, b.filtering);
        if (b.data) {
            var u = a.isFunction(b.data) ? b.data(t) : b.data;
            b.extraData = u, r = a.param(u, q)
        }
        if (b.beforeSubmit && b.beforeSubmit(t, this, b) === !1) return d("ajaxSubmit: submit aborted via beforeSubmit callback"), this;
        if (this.trigger("form-submit-validate", [t, this, b, p]), p.veto) return d("ajaxSubmit: submit vetoed via form-submit-validate trigger"), this;
        var v = a.param(t, q);
        r && (v = v ? v + "&" + r : r), "GET" === b.type.toUpperCase() ? (b.url += (b.url.indexOf("?") >= 0 ? "&" : "?") + v, b.data = null) : b.data = v;
        var w = [];
        if (b.resetForm && w.push(function() {
                o.resetForm()
            }), b.clearForm && w.push(function() {
                o.clearForm(b.includeHidden)
            }), !b.dataType && b.target) {
            var x = b.success || function() {};
            w.push(function(c, d, e) {
                var f = arguments,
                    g = b.replaceTarget ? "replaceWith" : "html";
                a(b.target)[g](c).each(function() {
                    x.apply(this, f)
                })
            })
        } else b.success && (a.isArray(b.success) ? a.merge(w, b.success) : w.push(b.success));
        if (b.success = function(a, c, d) {
                for (var e = b.context || this, f = 0, g = w.length; f < g; f++) w[f].apply(e, [a, c, d || o, o])
            }, b.error) {
            var y = b.error;
            b.error = function(a, c, d) {
                var e = b.context || this;
                y.apply(e, [a, c, d, o])
            }
        }
        if (b.complete) {
            var z = b.complete;
            b.complete = function(a, c) {
                var d = b.context || this;
                z.apply(d, [a, c, o])
            }
        }
        var A = a("input[type=file]:enabled", this).filter(function() {
                return "" !== a(this).val()
            }),
            B = A.length > 0,
            C = "multipart/form-data",
            D = o.attr("enctype") === C || o.attr("encoding") === C,
            E = f.fileapi && f.formdata;
        d("fileAPI :" + E);
        var F, G = (B || D) && !E;
        b.iframe !== !1 && (b.iframe || G) ? b.closeKeepAlive ? a.get(b.closeKeepAlive, function() {
            F = k(t)
        }) : F = k(t) : F = (B || D) && E ? j(t) : a.ajax(b), o.removeData("jqxhr").data("jqxhr", F);
        for (var H = 0; H < s.length; H++) s[H] = null;
        return this.trigger("form-submit-notify", [this, b]), this
    }, a.fn.ajaxForm = function(e, f, g, h) {
        if (("string" == typeof e || e === !1 && arguments.length > 0) && (e = {
                url: e,
                data: f,
                dataType: g
            }, "function" == typeof h && (e.success = h)), e = e || {}, e.delegation = e.delegation && a.isFunction(a.fn.on), !e.delegation && 0 === this.length) {
            var i = {
                s: this.selector,
                c: this.context
            };
            return !a.isReady && i.s ? (d("DOM not ready, queuing ajaxForm"), a(function() {
                a(i.s, i.c).ajaxForm(e)
            }), this) : (d("terminating; zero elements found by selector" + (a.isReady ? "" : " (DOM not ready)")), this)
        }
        return e.delegation ? (a(document).off("submit.form-plugin", this.selector, b).off("click.form-plugin", this.selector, c).on("submit.form-plugin", this.selector, e, b).on("click.form-plugin", this.selector, e, c), this) : this.ajaxFormUnbind().on("submit.form-plugin", e, b).on("click.form-plugin", e, c)
    }, a.fn.ajaxFormUnbind = function() {
        return this.off("submit.form-plugin click.form-plugin")
    }, a.fn.formToArray = function(b, c, d) {
        var e = [];
        if (0 === this.length) return e;
        var g, h = this[0],
            i = this.attr("id"),
            j = b || "undefined" == typeof h.elements ? h.getElementsByTagName("*") : h.elements;
        if (j && (j = a.makeArray(j)), i && (b || /(Edge|Trident)\//.test(navigator.userAgent)) && (g = a(':input[form="' + i + '"]').get(), g.length && (j = (j || []).concat(g))), !j || !j.length) return e;
        a.isFunction(d) && (j = a.map(j, d));
        var k, l, m, n, o, p, q;
        for (k = 0, p = j.length; k < p; k++)
            if (o = j[k], m = o.name, m && !o.disabled)
                if (b && h.clk && "image" === o.type) h.clk === o && (e.push({
                    name: m,
                    value: a(o).val(),
                    type: o.type
                }), e.push({
                    name: m + ".x",
                    value: h.clk_x
                }, {
                    name: m + ".y",
                    value: h.clk_y
                }));
                else if (n = a.fieldValue(o, !0), n && n.constructor === Array)
            for (c && c.push(o), l = 0, q = n.length; l < q; l++) e.push({
                name: m,
                value: n[l]
            });
        else if (f.fileapi && "file" === o.type) {
            c && c.push(o);
            var r = o.files;
            if (r.length)
                for (l = 0; l < r.length; l++) e.push({
                    name: m,
                    value: r[l],
                    type: o.type
                });
            else e.push({
                name: m,
                value: "",
                type: o.type
            })
        } else null !== n && "undefined" != typeof n && (c && c.push(o), e.push({
            name: m,
            value: n,
            type: o.type,
            required: o.required
        }));
        if (!b && h.clk) {
            var s = a(h.clk),
                t = s[0];
            m = t.name, m && !t.disabled && "image" === t.type && (e.push({
                name: m,
                value: s.val()
            }), e.push({
                name: m + ".x",
                value: h.clk_x
            }, {
                name: m + ".y",
                value: h.clk_y
            }))
        }
        return e
    }, a.fn.formSerialize = function(b) {
        return a.param(this.formToArray(b))
    }, a.fn.fieldSerialize = function(b) {
        var c = [];
        return this.each(function() {
            var d = this.name;
            if (d) {
                var e = a.fieldValue(this, b);
                if (e && e.constructor === Array)
                    for (var f = 0, g = e.length; f < g; f++) c.push({
                        name: d,
                        value: e[f]
                    });
                else null !== e && "undefined" != typeof e && c.push({
                    name: this.name,
                    value: e
                })
            }
        }), a.param(c)
    }, a.fn.fieldValue = function(b) {
        for (var c = [], d = 0, e = this.length; d < e; d++) {
            var f = this[d],
                g = a.fieldValue(f, b);
            null === g || "undefined" == typeof g || g.constructor === Array && !g.length || (g.constructor === Array ? a.merge(c, g) : c.push(g))
        }
        return c
    }, a.fieldValue = function(b, c) {
        var d = b.name,
            f = b.type,
            g = b.tagName.toLowerCase();
        if ("undefined" == typeof c && (c = !0), c && (!d || b.disabled || "reset" === f || "button" === f || ("checkbox" === f || "radio" === f) && !b.checked || ("submit" === f || "image" === f) && b.form && b.form.clk !== b || "select" === g && b.selectedIndex === -1)) return null;
        if ("select" === g) {
            var h = b.selectedIndex;
            if (h < 0) return null;
            for (var i = [], j = b.options, k = "select-one" === f, l = k ? h + 1 : j.length, m = k ? h : 0; m < l; m++) {
                var n = j[m];
                if (n.selected && !n.disabled) {
                    var o = n.value;
                    if (o || (o = n.attributes && n.attributes.value && !n.attributes.value.specified ? n.text : n.value), k) return o;
                    i.push(o)
                }
            }
            return i
        }
        return a(b).val().replace(e, "\r\n")
    }, a.fn.clearForm = function(b) {
        return this.each(function() {
            a("input,select,textarea", this).clearFields(b)
        })
    }, a.fn.clearFields = a.fn.clearInputs = function(b) {
        var c = /^(?:color|date|datetime|email|month|number|password|range|search|tel|text|time|url|week)$/i;
        return this.each(function() {
            var d = this.type,
                e = this.tagName.toLowerCase();
            c.test(d) || "textarea" === e ? this.value = "" : "checkbox" === d || "radio" === d ? this.checked = !1 : "select" === e ? this.selectedIndex = -1 : "file" === d ? /MSIE/.test(navigator.userAgent) ? a(this).replaceWith(a(this).clone(!0)) : a(this).val("") : b && (b === !0 && /hidden/.test(d) || "string" == typeof b && a(this).is(b)) && (this.value = "")
        })
    }, a.fn.resetForm = function() {
        return this.each(function() {
            var b = a(this),
                c = this.tagName.toLowerCase();
            switch (c) {
                case "input":
                    this.checked = this.defaultChecked;
                case "textarea":
                    return this.value = this.defaultValue, !0;
                case "option":
                case "optgroup":
                    var d = b.parents("select");
                    return d.length && d[0].multiple ? "option" === c ? this.selected = this.defaultSelected : b.find("option").resetForm() : d.resetForm(), !0;
                case "select":
                    return b.find("option").each(function(a) {
                        if (this.selected = this.defaultSelected, this.defaultSelected && !b[0].multiple) return b[0].selectedIndex = a, !1
                    }), !0;
                case "label":
                    var e = a(b.attr("for")),
                        f = b.find("input,select,textarea");
                    return e[0] && f.unshift(e[0]), f.resetForm(), !0;
                case "form":
                    return ("function" == typeof this.reset || "object" == typeof this.reset && !this.reset.nodeType) && this.reset(), !0;
                default:
                    return b.find("form,input,label,select,textarea").resetForm(), !0
            }
        })
    }, a.fn.enable = function(a) {
        return "undefined" == typeof a && (a = !0), this.each(function() {
            this.disabled = !a
        })
    }, a.fn.selected = function(b) {
        return "undefined" == typeof b && (b = !0), this.each(function() {
            var c = this.type;
            if ("checkbox" === c || "radio" === c) this.checked = b;
            else if ("option" === this.tagName.toLowerCase()) {
                var d = a(this).parent("select");
                b && d[0] && "select-one" === d[0].type && d.find("option").selected(!1), this.selected = b
            }
        })
    }, a.fn.ajaxSubmit.debug = !1
});;;

/*! Lity - v2.2.2 - 2017-07-17
 * http://sorgalla.com/lity/
 * Copyright (c) 2015-2017 Jan Sorgalla; Licensed MIT */
(function(window, factory) {
    if (typeof define === 'function' && define.amd) {
        define(['jquery'], function($) {
            return factory(window, $);
        });
    } else if (typeof module === 'object' && typeof module.exports === 'object') {
        module.exports = factory(window, require('jquery'));
    } else {
        window.lity = factory(window, window.jQuery || window.Zepto);
    }
}(typeof window !== "undefined" ? window : this, function(window, $) {
    'use strict';
    var document = window.document;
    var _win = $(window);
    var _deferred = $.Deferred;
    var _html = $('html');
    var _instances = [];
    var _attrAriaHidden = 'aria-hidden';
    var _dataAriaHidden = 'lity-' + _attrAriaHidden;
    var _focusableElementsSelector = 'a[href],area[href],input:not([disabled]),select:not([disabled]),textarea:not([disabled]),button:not([disabled]),iframe,object,embed,[contenteditable],[tabindex]:not([tabindex^="-"])';
    var _defaultOptions = {
        esc: true,
        handler: null,
        handlers: {
            image: imageHandler,
            inline: inlineHandler,
            youtube: youtubeHandler,
            vimeo: vimeoHandler,
            googlemaps: googlemapsHandler,
            facebookvideo: facebookvideoHandler,
            iframe: iframeHandler
        },
        template: '<div class="lity" role="dialog" aria-label="Dialog Window (Press escape to close)" tabindex="-1"><div class="lity-wrap" data-lity-close role="document"><div class="lity-loader" aria-hidden="true">Loading...</div><div class="lity-container"><div class="lity-content"></div><button class="lity-close" type="button" aria-label="Close (Press escape to close)" data-lity-close>&times;</button></div></div></div>'
    };
    var _imageRegexp = /(^data:image\/)|(\.(png|jpe?g|gif|svg|webp|bmp|ico|tiff?)(\?\S*)?$)/i;
    var _youtubeRegex = /(youtube(-nocookie)?\.com|youtu\.be)\/(watch\?v=|v\/|u\/|embed\/?)?([\w-]{11})(.*)?/i;
    var _vimeoRegex = /(vimeo(pro)?.com)\/(?:[^\d]+)?(\d+)\??(.*)?$/;
    var _googlemapsRegex = /((maps|www)\.)?google\.([^\/\?]+)\/?((maps\/?)?\?)(.*)/i;
    var _facebookvideoRegex = /(facebook\.com)\/([a-z0-9_-]*)\/videos\/([0-9]*)(.*)?$/i;
    var _transitionEndEvent = (function() {
        var el = document.createElement('div');
        var transEndEventNames = {
            WebkitTransition: 'webkitTransitionEnd',
            MozTransition: 'transitionend',
            OTransition: 'oTransitionEnd otransitionend',
            transition: 'transitionend'
        };
        for (var name in transEndEventNames) {
            if (el.style[name] !== undefined) {
                return transEndEventNames[name];
            }
        }
        return false;
    })();

    function transitionEnd(element) {
        var deferred = _deferred();
        if (!_transitionEndEvent || !element.length) {
            deferred.resolve();
        } else {
            element.one(_transitionEndEvent, deferred.resolve);
            setTimeout(deferred.resolve, 500);
        }
        return deferred.promise();
    }

    function settings(currSettings, key, value) {
        if (arguments.length === 1) {
            return $.extend({}, currSettings);
        }
        if (typeof key === 'string') {
            if (typeof value === 'undefined') {
                return typeof currSettings[key] === 'undefined' ? null : currSettings[key];
            }
            currSettings[key] = value;
        } else {
            $.extend(currSettings, key);
        }
        return this;
    }

    function parseQueryParams(params) {
        var pairs = decodeURI(params.split('#')[0]).split('&');
        var obj = {},
            p;
        for (var i = 0, n = pairs.length; i < n; i++) {
            if (!pairs[i]) {
                continue;
            }
            p = pairs[i].split('=');
            obj[p[0]] = p[1];
        }
        return obj;
    }

    function appendQueryParams(url, params) {
        return url + (url.indexOf('?') > -1 ? '&' : '?') + $.param(params);
    }

    function transferHash(originalUrl, newUrl) {
        var pos = originalUrl.indexOf('#');
        if (-1 === pos) {
            return newUrl;
        }
        if (pos > 0) {
            originalUrl = originalUrl.substr(pos);
        }
        return newUrl + originalUrl;
    }

    function error(msg) {
        return $('<span class="lity-error"/>').append(msg);
    }

    function imageHandler(target, instance) {
        var desc = (instance.opener() && instance.opener().data('lity-desc')) || 'Image with no description';
        var img = $('<img src="' + target + '" alt="' + desc + '"/>');
        var deferred = _deferred();
        var failed = function() {
            deferred.reject(error('Failed loading image'));
        };
        img.on('load', function() {
            if (this.naturalWidth === 0) {
                return failed();
            }
            deferred.resolve(img);
        }).on('error', failed);
        return deferred.promise();
    }
    imageHandler.test = function(target) {
        return _imageRegexp.test(target);
    };

    function inlineHandler(target, instance) {
        var el, placeholder, hasHideClass;
        try {
            el = $(target);
        } catch (e) {
            return false;
        }
        if (!el.length) {
            return false;
        }
        placeholder = $('<i style="display:none !important"/>');
        hasHideClass = el.hasClass('lity-hide');
        instance.element().one('lity:remove', function() {
            placeholder.before(el).remove();
            if (hasHideClass && !el.closest('.lity-content').length) {
                el.addClass('lity-hide');
            }
        });
        return el.removeClass('lity-hide').after(placeholder);
    }

    function youtubeHandler(target) {
        var matches = _youtubeRegex.exec(target);
        if (!matches) {
            return false;
        }
        return iframeHandler(transferHash(target, appendQueryParams('https://www.youtube' + (matches[2] || '') + '.com/embed/' + matches[4], $.extend({
            autoplay: 1
        }, parseQueryParams(matches[5] || '')))));
    }

    function vimeoHandler(target) {
        var matches = _vimeoRegex.exec(target);
        if (!matches) {
            return false;
        }
        return iframeHandler(transferHash(target, appendQueryParams('https://player.vimeo.com/video/' + matches[3], $.extend({
            autoplay: 1
        }, parseQueryParams(matches[4] || '')))));
    }

    function facebookvideoHandler(target) {
        var matches = _facebookvideoRegex.exec(target);
        if (!matches) {
            return false;
        }
        if (0 !== target.indexOf('http')) {
            target = 'https:' + target;
        }
        return iframeHandler(transferHash(target, appendQueryParams('https://www.facebook.com/plugins/video.php?href=' + target, $.extend({
            autoplay: 1
        }, parseQueryParams(matches[4] || '')))));
    }

    function googlemapsHandler(target) {
        var matches = _googlemapsRegex.exec(target);
        if (!matches) {
            return false;
        }
        return iframeHandler(transferHash(target, appendQueryParams('https://www.google.' + matches[3] + '/maps?' + matches[6], {
            output: matches[6].indexOf('layer=c') > 0 ? 'svembed' : 'embed'
        })));
    }

    function iframeHandler(target) {
        return '<div class="lity-iframe-container"><iframe frameborder="0" allowfullscreen src="' + target + '"/></div>';
    }

    function winHeight() {
        return document.documentElement.clientHeight ? document.documentElement.clientHeight * 0.9 : Math.round(_win.height() * 0.9);
    }

    function keydown(e) {
        var current = currentInstance();
        if (!current) {
            return;
        }
        if (e.keyCode === 27 && !!current.options('esc')) {
            current.close();
        }
        if (e.keyCode === 9) {
            handleTabKey(e, current);
        }
    }

    function handleTabKey(e, instance) {
        var focusableElements = instance.element().find(_focusableElementsSelector);
        var focusedIndex = focusableElements.index(document.activeElement);
        if (e.shiftKey && focusedIndex <= 0) {
            focusableElements.get(focusableElements.length - 1).focus();
            e.preventDefault();
        } else if (!e.shiftKey && focusedIndex === focusableElements.length - 1) {
            focusableElements.get(0).focus();
            e.preventDefault();
        }
    }

    function resize() {
        $.each(_instances, function(i, instance) {
            instance.resize();
        });
    }

    function registerInstance(instanceToRegister) {
        if (1 === _instances.unshift(instanceToRegister)) {
            _html.addClass('lity-active');
            _win.on({
                resize: resize,
                keydown: keydown
            });
        }
        $('body > *').not(instanceToRegister.element()).addClass('lity-hidden').each(function() {
            var el = $(this);
            if (undefined !== el.data(_dataAriaHidden)) {
                return;
            }
            el.data(_dataAriaHidden, el.attr(_attrAriaHidden) || null);
        }).attr(_attrAriaHidden, 'true');
    }

    function removeInstance(instanceToRemove) {
        var show;
        instanceToRemove.element().attr(_attrAriaHidden, 'true');
        if (1 === _instances.length) {
            _html.removeClass('lity-active');
            _win.off({
                resize: resize,
                keydown: keydown
            });
        }
        _instances = $.grep(_instances, function(instance) {
            return instanceToRemove !== instance;
        });
        if (!!_instances.length) {
            show = _instances[0].element();
        } else {
            show = $('.lity-hidden');
        }
        show.removeClass('lity-hidden').each(function() {
            var el = $(this),
                oldAttr = el.data(_dataAriaHidden);
            if (!oldAttr) {
                el.removeAttr(_attrAriaHidden);
            } else {
                el.attr(_attrAriaHidden, oldAttr);
            }
            el.removeData(_dataAriaHidden);
        });
    }

    function currentInstance() {
        if (0 === _instances.length) {
            return null;
        }
        return _instances[0];
    }

    function factory(target, instance, handlers, preferredHandler) {
        var handler = 'inline',
            content;
        var currentHandlers = $.extend({}, handlers);
        if (preferredHandler && currentHandlers[preferredHandler]) {
            content = currentHandlers[preferredHandler](target, instance);
            handler = preferredHandler;
        } else {
            $.each(['inline', 'iframe'], function(i, name) {
                delete currentHandlers[name];
                currentHandlers[name] = handlers[name];
            });
            $.each(currentHandlers, function(name, currentHandler) {
                if (!currentHandler) {
                    return true;
                }
                if (currentHandler.test && !currentHandler.test(target, instance)) {
                    return true;
                }
                content = currentHandler(target, instance);
                if (false !== content) {
                    handler = name;
                    return false;
                }
            });
        }
        return {
            handler: handler,
            content: content || ''
        };
    }

    function Lity(target, options, opener, activeElement) {
        var self = this;
        var result;
        var isReady = false;
        var isClosed = false;
        var element;
        var content;
        options = $.extend({}, _defaultOptions, options);
        element = $(options.template);
        self.element = function() {
            return element;
        };
        self.opener = function() {
            return opener;
        };
        self.options = $.proxy(settings, self, options);
        self.handlers = $.proxy(settings, self, options.handlers);
        self.resize = function() {
            if (!isReady || isClosed) {
                return;
            }
            content.css('max-height', winHeight() + 'px').trigger('lity:resize', [self]);
        };
        self.close = function() {
            if (!isReady || isClosed) {
                return;
            }
            isClosed = true;
            removeInstance(self);
            var deferred = _deferred();
            if (activeElement && (document.activeElement === element[0] || $.contains(element[0], document.activeElement))) {
                try {
                    activeElement.focus();
                } catch (e) {}
            }
            content.trigger('lity:close', [self]);
            element.removeClass('lity-opened').addClass('lity-closed');
            transitionEnd(content.add(element)).always(function() {
                content.trigger('lity:remove', [self]);
                element.remove();
                element = undefined;
                deferred.resolve();
            });
            return deferred.promise();
        };
        result = factory(target, self, options.handlers, options.handler);
        element.attr(_attrAriaHidden, 'false').addClass('lity-loading lity-opened lity-' + result.handler).appendTo('body').focus().on('click', '[data-lity-close]', function(e) {
            if ($(e.target).is('[data-lity-close]')) {
                self.close();
            }
        }).trigger('lity:open', [self]);
        registerInstance(self);
        $.when(result.content).always(ready);

        function ready(result) {
            content = $(result).css('max-height', winHeight() + 'px');
            element.find('.lity-loader').each(function() {
                var loader = $(this);
                transitionEnd(loader).always(function() {
                    loader.remove();
                });
            });
            element.removeClass('lity-loading').find('.lity-content').empty().append(content);
            isReady = true;
            content.trigger('lity:ready', [self]);
        }
    }

    function wpdLity(target, options, opener) {
        if (!target.preventDefault) {
            opener = $(opener);
        } else {
            target.preventDefault();
            opener = $(this);
            target = opener.data('lity-target') || opener.attr('rel') || opener.attr('src');
        }
        var instance = new Lity(target, $.extend({}, opener.data('lity-options') || opener.data('lity'), options), opener, document.activeElement);
        if (!target.preventDefault) {
            return instance;
        }
    }
    wpdLity.version = '2.2.2';
    wpdLity.options = $.proxy(settings, wpdLity, _defaultOptions);
    wpdLity.handlers = $.proxy(settings, wpdLity, _defaultOptions.handlers);
    wpdLity.current = currentInstance;
    $(document).on('click.lity', '[data-wpd-lity]', wpdLity);
    return wpdLity;
}));;
! function(a, b) {
    "use strict";

    function c() {
        if (!e) {
            e = !0;
            var a, c, d, f, g = -1 !== navigator.appVersion.indexOf("MSIE 10"),
                h = !!navigator.userAgent.match(/Trident.*rv:11\./),
                i = b.querySelectorAll("iframe.wp-embedded-content");
            for (c = 0; c < i.length; c++) {
                if (d = i[c], !d.getAttribute("data-secret")) f = Math.random().toString(36).substr(2, 10), d.src += "#?secret=" + f, d.setAttribute("data-secret", f);
                if (g || h) a = d.cloneNode(!0), a.removeAttribute("security"), d.parentNode.replaceChild(a, d)
            }
        }
    }
    var d = !1,
        e = !1;
    if (b.querySelector)
        if (a.addEventListener) d = !0;
    if (a.wp = a.wp || {}, !a.wp.receiveEmbedMessage)
        if (a.wp.receiveEmbedMessage = function(c) {
                var d = c.data;
                if (d)
                    if (d.secret || d.message || d.value)
                        if (!/[^a-zA-Z0-9]/.test(d.secret)) {
                            var e, f, g, h, i, j = b.querySelectorAll('iframe[data-secret="' + d.secret + '"]'),
                                k = b.querySelectorAll('blockquote[data-secret="' + d.secret + '"]');
                            for (e = 0; e < k.length; e++) k[e].style.display = "none";
                            for (e = 0; e < j.length; e++)
                                if (f = j[e], c.source === f.contentWindow) {
                                    if (f.removeAttribute("style"), "height" === d.message) {
                                        if (g = parseInt(d.value, 10), g > 1e3) g = 1e3;
                                        else if (~~g < 200) g = 200;
                                        f.height = g
                                    }
                                    if ("link" === d.message)
                                        if (h = b.createElement("a"), i = b.createElement("a"), h.href = f.getAttribute("src"), i.href = d.value, i.host === h.host)
                                            if (b.activeElement === f) a.top.location.href = d.value
                                } else;
                        }
            }, d) a.addEventListener("message", a.wp.receiveEmbedMessage, !1), b.addEventListener("DOMContentLoaded", c, !1), a.addEventListener("load", c, !1)
}(window, document);;
var _extends = Object.assign || function(t) {
        for (var e = 1; e < arguments.length; e++) {
            var n = arguments[e];
            for (var o in n) Object.prototype.hasOwnProperty.call(n, o) && (t[o] = n[o])
        }
        return t
    },
    _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(t) {
        return typeof t
    } : function(t) {
        return t && "function" == typeof Symbol && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t
    };
! function(t, e) {
    "object" === ("undefined" == typeof exports ? "undefined" : _typeof(exports)) && "undefined" != typeof module ? module.exports = e() : "function" == typeof define && define.amd ? define(e) : t.LazyLoad = e()
}(this, function() {
    "use strict";
    var n = {
            elements_selector: "img",
            container: document,
            threshold: 300,
            thresholds: null,
            data_src: "src",
            data_srcset: "srcset",
            data_sizes: "sizes",
            data_bg: "bg",
            class_loading: "litespeed-loading",
            class_loaded: "litespeed-loaded",
            class_error: "error",
            load_delay: 0,
            callback_load: null,
            callback_error: null,
            callback_set: null,
            callback_enter: null,
            callback_finish: null,
            to_webp: !1
        },
        s = "data-",
        r = "was-processed",
        o = "ll-timeout",
        a = "true",
        c = function(t, e) {
            return t.getAttribute(s + e)
        },
        i = function(t, e, n) {
            var o = s + e;
            null !== n ? t.setAttribute(o, n) : t.removeAttribute(o)
        },
        l = function(t) {
            return c(t, r) === a
        },
        u = function(t, e) {
            return i(t, o, e)
        },
        d = function(t) {
            return c(t, o)
        },
        f = function(t, e) {
            var n, o = "LazyLoad::Initialized",
                s = new t(e);
            try {
                n = new CustomEvent(o, {
                    detail: {
                        instance: s
                    }
                })
            } catch (t) {
                (n = document.createEvent("CustomEvent")).initCustomEvent(o, !1, !1, {
                    instance: s
                })
            }
            window.dispatchEvent(n)
        };
    var _ = function(t, e) {
            return e ? t.replace(/\.(jpe?g|png)/gi, ".webp") : t
        },
        t = "undefined" != typeof window,
        v = t && !("onscroll" in window) || /(gle|ing|ro)bot|crawl|spider/i.test(navigator.userAgent),
        e = t && "IntersectionObserver" in window,
        h = t && "classList" in document.createElement("p"),
        b = t && !1,
        g = function(t, e, n, o) {
            for (var s, r = 0; s = t.children[r]; r += 1)
                if ("SOURCE" === s.tagName) {
                    var a = c(s, n);
                    m(s, e, a, o)
                }
        },
        m = function(t, e, n, o) {
            n && t.setAttribute(e, _(n, o))
        },
        p = {
            IMG: function(t, e) {
                var n = b && e.to_webp,
                    o = e.data_srcset,
                    s = t.parentNode;
                s && "PICTURE" === s.tagName && g(s, "srcset", o, n);
                var r = c(t, e.data_sizes);
                m(t, "sizes", r);
                var a = c(t, o);
                m(t, "srcset", a, n);
                var i = c(t, e.data_src);
                m(t, "src", i, n)
            },
            IFRAME: function(t, e) {
                var n = c(t, e.data_src);
                m(t, "src", n)
            },
            VIDEO: function(t, e) {
                var n = e.data_src,
                    o = c(t, n);
                g(t, "src", n), m(t, "src", o), t.load()
            }
        },
        y = function(t, e) {
            var n, o, s = e._settings,
                r = t.tagName,
                a = p[r];
            if (a) return a(t, s), e._updateLoadingCount(1), void(e._elements = (n = e._elements, o = t, n.filter(function(t) {
                return t !== o
            })));
            ! function(t, e) {
                var n = b && e.to_webp,
                    o = c(t, e.data_src),
                    s = c(t, e.data_bg);
                if (o) {
                    var r = _(o, n);
                    t.style.backgroundImage = 'url("' + r + '")'
                }
                if (s) {
                    var a = _(s, n);
                    t.style.backgroundImage = a
                }
            }(t, s)
        },
        w = function(t, e) {
            h ? t.classList.add(e) : t.className += (t.className ? " " : "") + e
        },
        E = function(t, e) {
            t && t(e)
        },
        L = "load",
        I = "loadeddata",
        O = "error",
        k = function(t, e, n) {
            t.addEventListener(e, n)
        },
        A = function(t, e, n) {
            t.removeEventListener(e, n)
        },
        C = function(t, e, n) {
            A(t, L, e), A(t, I, e), A(t, O, n)
        },
        z = function(t, e, n) {
            var o, s, r = n._settings,
                a = e ? r.class_loaded : r.class_error,
                i = e ? r.callback_load : r.callback_error,
                c = t.target;
            o = c, s = r.class_loading, h ? o.classList.remove(s) : o.className = o.className.replace(new RegExp("(^|\\s+)" + s + "(\\s+|$)"), " ").replace(/^\s+/, "").replace(/\s+$/, ""), w(c, a), E(i, c), n._updateLoadingCount(-1)
        },
        N = function(n, o) {
            var t, e, s, r = function t(e) {
                    z(e, !0, o), C(n, t, a)
                },
                a = function t(e) {
                    z(e, !1, o), C(n, r, t)
                };
            s = a, k(t = n, L, e = r), k(t, I, e), k(t, O, s)
        },
        x = ["IMG", "IFRAME", "VIDEO"],
        M = function(t, e, n) {
            R(t, n), e.unobserve(t)
        },
        S = function(t) {
            var e = d(t);
            e && (clearTimeout(e), u(t, null))
        };

    function R(t, e, n) {
        var o = e._settings;
        !n && l(t) || (E(o.callback_enter, t), -1 < x.indexOf(t.tagName) && (N(t, e), w(t, o.class_loading)), y(t, e), i(t, r, a), E(o.callback_set, t))
    }
    var j = function(t) {
            return t.isIntersecting || 0 < t.intersectionRatio
        },
        T = function(t, e) {
            this._settings = _extends({}, n, t), this._setObserver(), this._loadingCount = 0, this.update(e)
        };
    return T.prototype = {
        _manageIntersection: function(t) {
            var e, n, o, s, r, a = this._observer,
                i = this._settings.load_delay,
                c = t.target;
            i ? j(t) ? (e = c, n = a, s = (o = this)._settings.load_delay, (r = d(e)) || (r = setTimeout(function() {
                M(e, n, o), S(e)
            }, s), u(e, r))) : S(c) : j(t) && M(c, a, this)
        },
        _onIntersection: function(t) {
            t.forEach(this._manageIntersection.bind(this))
        },
        _setObserver: function() {
            var t;
            e && (this._observer = new IntersectionObserver(this._onIntersection.bind(this), {
                root: (t = this._settings).container === document ? null : t.container,
                rootMargin: t.thresholds || t.threshold + "px"
            }))
        },
        _updateLoadingCount: function(t) {
            this._loadingCount += t, 0 === this._elements.length && 0 === this._loadingCount && E(this._settings.callback_finish)
        },
        update: function(t) {
            var e = this,
                n = this._settings,
                o = t || n.container.querySelectorAll(n.elements_selector);
            this._elements = Array.prototype.slice.call(o).filter(function(t) {
                return !l(t)
            }), !v && this._observer ? this._elements.forEach(function(t) {
                e._observer.observe(t)
            }) : this.loadAll()
        },
        destroy: function() {
            var e = this;
            this._observer && (this._elements.forEach(function(t) {
                e._observer.unobserve(t)
            }), this._observer = null), this._elements = null, this._settings = null
        },
        load: function(t, e) {
            R(t, this, e)
        },
        loadAll: function() {
            var e = this;
            this._elements.forEach(function(t) {
                e.load(t)
            })
        }
    }, t && function(t, e) {
        if (e)
            if (e.length)
                for (var n, o = 0; n = e[o]; o += 1) f(t, n);
            else f(t, e)
    }(T, window.lazyLoadOptions), T
}),
function(t, e) {
}(window, document);
	

	
});



 

































(function($) {

var ref=document.referrer;
if (ref.indexOf("rahvar120.ir")==-1 ) {
  
 //window.location.href="/index.jsp?fkeyid=&siteid=1&fkeyid=&siteid=1&pageid=2540" ; 

} 

	var price;
	var CBCount;
	var CBCheckedCount;
	var SumCB;
	var rowCount;
	var MainString = "";
	var temp = 0;
	var sum = 0;
	var ErrorNumbers = "";
	var TempCount = 0;
	var Inputs = 0;
	
	price=$("#warning_price").text(); 

	
  
function Loading()
{
	$("#progress-bar").slideUp("slow");
	$("#SpnSumPrices").text(addCommas(GetSum())+" "+"ریال");
}

function ManageSelectAll()
{
	if(TempCount == Inputs)
	{
		$("#s1").css('display','none');
	}
	else if(TempCount < Inputs)
	{
		$("#s1").css('display','block');
	}
	else{}
}

function CheckWrongInputs()
{
	$('#t1 input[tb=cb]').each(function()
	{
		if($(this).attr('payment') == "" || $(this).attr('paper') == "")
		{
			TempCount ++;
			
			$(this).attr('type','image');
			$(this).attr('src','/uploads/disableicon.png');
			$(this).attr('data-original-title','به دلیل عدم وجود شناسه پرداخت و شناسه قبض این ردیف قابل پرداخت آنلاین نمی باشد');
			
			ErrorNumbers += $(this).attr('serial') + ', ';
		}
	});
}

$(document).ready(function()
{
	Inputs = ($('#t1 input').length)/2;

	//$("#progress-bar").slideDown("slow");

	$('#t1 input[tb=cb]').css('float','right');

	CheckWrongInputs();
	
	ManageSelectAll();

	ErrorNumbers = ErrorNumbers.substring(0,ErrorNumbers.length-2);
	//$("#desc").text(ErrorNumbers);

var slc = $('#slc');
	slc.selectedIndex = 1;

	CBCount = $('#t1 input[type=checkbox]').length;
	CBCount1 = $('table tbody tr').length;

	$("#jam").text(CBCount1+" "+"عدد");
	$("#t1").find("input[name=rd]").css('display', 'none');
	$("#t1").find("input[type=checkbox]").attr('am', 'za');

	rowCount = $('#t1 tr').length;
	temp = 0;
	sum = 0;
	MainString = "";

	$('#ifrm').contents().find('#cr').val(0);
	$('#ifrm').contents().find('#bmibills').val("");
	$('#ifrm2').contents().find('#cr').val(0);
	$('#ifrm2').contents().find('#pecbills').val("");

	$('#ifrm3').contents().find('#cr').val(0);
	$('#ifrm3').contents().find('#samanbills').val("");
	$('#ifrm5').contents().find('#billinfo').val("");
		
	$('table tbody :checkbox').change(function (event)
	{
		$(this).closest('tr').toggleClass("selected_row", this.checked);
	});
	

});

function CheckIframeInputs()
{
	var cr = $('#ifrm').contents().find('#cr').val();
	var BmiBills = $('#ifrm').contents().find('#bmibills').val();
	
	if(cr == "" || BmiBills == "" || MainString == "")
	{
		alert('شما می بایست یک مورد را انتخاب نمایید');
	}
	else
	{
        var mychoice=  $(".selectpay:checked").attr("data-load");
		if (mychoice == undefined || mychoice == "" ) {
			alert('درگاه پرداخت مورد نظرتان را انتخاب کنید.');
			return false;
		}else{
			$("#"+mychoice).contents().find('#submit').trigger("click");
		}
		//$('#ifrm').contents().find('#submit').trigger("click");
	}
}

function Checker()
{
    var e = document.getElementById('slc');
    var c = e.value;
                
   if(c == 1)
   {
		ManageSelectAll();

		$('#ifrm').contents().find('#bmibills').val("");
		$("#pay").attr('disabled','disabled');
		
		$('#t1 input[tb=cb]').each(function()
		{
			if($(this).attr('payment') == "" || $(this).attr('paper') == "")
			{
				$(this).attr('type','image');
				$(this).attr('src','/uploads/disableicon.png');
				$(this).attr('data-original-title','به دلیل عدم وجود شناسه پرداخت و شناسه قبض این ردیف قابل پرداخت آنلاین نمی باشد');
			}
		}); 

        $("#t1").find("input[name=rd]").css('display', 'none');
        $("#t1").find("input[type=checkbox]").css('display', 'block');
        $('table tbody tr').css({'background-color' : '#efefef' , 'color' :'#444444'}); 
        $("tr").removeClass( "selected_row" ); 
			
        sum = 0;
		CBCheckedCount = 0;
		$("#CBCheckedCount").text('0 عدد');
        
        $("#SelectedSum").text(addCommas(sum)+" "+"ریال");
		$("#SpnSumPrices").text(addCommas(GetSum())+" "+"ریال");
   }
   else if(c == 2)
   {	
		ManageSelectAll();

		$('#ifrm').contents().find('#bmibills').val("");  
		$("#pay").attr('disabled','disabled');
		
		$('#t1 input[name=rd]').each(function()
		{
			if($(this).attr('payment') == "" || $(this).attr('paper') == "")
			{
				$(this).attr('type','image');
				$(this).attr('src','/uploads/disableicon.png');
				$(this).attr('data-original-title','به دلیل عدم وجود شناسه پرداخت و شناسه قبض این ردیف قابل پرداخت آنلاین نمی باشد');
			}
		}); 
		
		$('#t1 input[tb=cb]').each(function()
		{
			if($(this).attr('payment') == "" || $(this).attr('paper') == "")
			{
				$(this).prop('type','hidden');
			}
		}); 
		
        $("#s1").css('display','none');
        $("#t1").find("input[name=rd]").css('display', 'block');
        $("#t1").find("input[name=rd]").prop('checked', false);
        $("#t1").find("input[type=checkbox]").css('display', 'none');
        $('table tbody tr').css({'background-color' : '#efefef' , 'color' :'#444444'}); 
        $( "tr" ).removeClass( "selected_row" ); 
		
        sum = 0;
		CBCheckedCount = 0;
		$("#CBCheckedCount").text('0 عدد');

		$("#SelectedSum").text(addCommas(sum+" "+"ریال"));
        $("#SpnSumPrices").text(addCommas(GetSum())+" "+"ریال");
		
        $('input[type=checkbox]').each(function()
        {
             $(this).prop('checked', false);                     
        }); 
   }
   else{}
}

function SelectAll(ele)
{
	var checkboxes = document.getElementsByTagName('input');
                
	if(ele.checked)
	{
		for (var i = 0; i < checkboxes.length; i++)
		{
			if (checkboxes[i].type == 'checkbox')
			{
				checkboxes[i].checked = true;
			}
		}
		
	$("#t1").find("input[am=za]:checked").each(function()
	{
		if (rowCount > 0)
		{
			if($(this).attr('payment') != ""|| $(this).attr('paper') != "")
			{
				$(this).closest('tr').addClass("selected_row"); 
			}
		}
	}); 

	}
	else
	{
		$('table tbody tr').css({'background-color' : '#efefef' , 'color' :'#444444'}); 
		$( "tr" ).removeClass( "selected_row" );
		
		for (var i = 0; i < checkboxes.length; i++)
		{
			if (checkboxes[i].type == 'checkbox')
			{
				checkboxes[i].checked = false;
			}
		}
	}
}

function GetSum1()
{
	var sumx = 0;
	var tempx = 0;
	
	$("#t1").find("input[type=checkbox]").each(function()
	{
		if(!$(this).attr('payment') == "" || $(this).attr('payment') == "")
		{
			tempx = parseInt($(this).attr('price'));
			sumx += tempx;
		}
	});
	
	return sumx;
}

function GetSum()
{
	var sumx = 0;
	var tempx = 0;

	$("#t1").find("input[price!='']").each(function()
	{
		tempx = parseInt($(this).attr('price'));
		sumx += tempx;
	});
	
	sumx = sumx/2;
	
	return sumx;
}


function Add(x)
{
	sum = 0;
	MainString = "";
	
	$("#t1").find("input[am=za]:checked").each(function()
	{
		if (rowCount > 0)
		{
			if($(this).attr('payment') == "" || $(this).attr('payment') == "")
			{
				$(this).removeAttr('checked');
				$(this).attr('data-original-title','به دلیل عدم وجود شناسه پرداخت و شناسه قبض این ردیف قابل پرداخت آنلاین نمی باشد');
			}
			else
			{
				temp = parseInt($(this).attr('price'));
				sum += temp;
				
				MainString += ($(this).attr('paper')) + ',' + ($(this).attr('payment')) + '|';
			}
		}
	});

	var tempx = MainString.split('|');

	MainString = MainString.substring(0,MainString.length-1);
	
	$("#SelectedSum").text(addCommas(sum)+" "+"ریال");
	$("#SpnSumPrices").text(addCommas(GetSum())+" "+"ریال");
	
	if(sum != 0)
	{
		$("#pay").removeAttr('disabled');
	}
	else
	{
		$("#pay").attr('disabled','disabled');
	}

	$('#ifrm').contents().find('#cr').val(0);
	$('#ifrm2').contents().find('#cr').val(0);
	$('#ifrm3').contents().find('#cr').val(0);

	$('#ifrm').contents().find('#bmibills').val(MainString);
	$('#ifrm2').contents().find('#pecbills').val(MainString);
	$('#ifrm3').contents().find('#samanbills').val(MainString);
	$('#ifrm4').contents().find('#sayanbills').val(MainString);
	$('#ifrm5').contents().find('#billinfo').val(MainString);

	var MainArray = MainString.split('|');
	
	for(var i=0;i<MainArray.length-1;i++)
	{              
		if (typeof MainArray[i] == 'undefined' ||  MainArray[i] == null ||  MainArray[i].length == 0)
		{
			alert(MainArray[i]);
		}
		else
		{}
	}

	
	
	if(MainString != "")
	{
		$("#pay").removeAttr('disabled');
	}
	
	$("#CBCheckedCount").text(($('#t1 input[type=checkbox]:checked').length) + ' عدد');
	
	return MainString;           
}

function AddOne(x)
{
	if($(x).attr('paper') == "" || $(x).attr('payment') == "")
	{
		$(this).removeAttr('checked');
		$(this).attr('data-original-title','به دلیل عدم وجود شناسه پرداخت و شناسه قبض این ردیف قابل پرداخت آنلاین نمی باشد');
	}
	else
	{
		MainString = "";
		MainString = ($(x).attr('paper')) + ',' + ($(x).attr('payment'));
		
		sum = ($(x).attr('price'));
		
		CBCheckedCount = 1;
		$("#CBCheckedCount").text('1 عدد');
		$("#SelectedSum").text(addCommas(sum)+" "+"ریال");
		
		if(sum != 0)
        {
			$("#pay").removeAttr('disabled');
        }
        else
        {
			$("#pay").attr('disabled','disabled');
        }
                                
		$("table tbody tr td input[type=radio]").each(function()
		{
			if($(this).is(":checked"))
			{
				$(this).closest("tr").css('background-color', "rgb(209,217,226)");
			} 
			else
			{
				$(this).closest("tr").css({'background-color'  :'#efefef', 'color' :'#444444'});
			}
	   });
   }

	$('#ifrm').contents().find('#cr').val(0);
	$('#ifrm1').contents().find('#refno').val(0);
	$('#ifrm2').contents().find('#cr').val(0);
	$('#ifrm3').contents().find('#cr').val(0);

	
	$('#ifrm').contents().find('#bmibills').val(MainString);
	$('#ifrm2').contents().find('#pecbills').val(MainString);
	$('#ifrm3').contents().find('#samanbills').val(MainString);
	$('#ifrm4').contents().find('#sayanbills').val(MainString);
	return MainString;
}




















})(jQuery);










































String.prototype.toPersinaDigit= function(){
 var id= ['۰','۱','۲','۳','۴','۵','۶','۷','۸','۹'];
 return this.replace(/[0-9]/g, function(w){
  return id[+w]
 });
}










//https://farmooon.com/wp-json/
function sr_during_ajax_request(){
	jQuery(".sr_loading").show();
}
function sr_complete_ajax_request(){
	jQuery(".sr_loading").hide();
}
function sr_ajax( hashtraghami ){
	//jQuery.ajax({
	//  type: "post",
	//  url:"http://estelam.rahvar120.ir/includes/services.jsp?serviceid=47",
	//  success:function(data){
	//   jQuery("#sr_ajax_target2").html(data);
	//  }
	//  
	//});
	sr_during_ajax_request();
	jQuery.ajax({
		type: "POST",
		url: pefix_handel.name_1,
		data: {
			action: 'estelam_rahvar_ajax',
			'hashtraghami': hashtraghami,
			'ajax_type': 'get_data_no_cpthca',
		},
		success: function(msg) {
			//jQuery('#sr_ajax_target').html(msg);
			jQuery('#sr_ajax_target2').html(msg);
		},
		complete: function() {
			sr_complete_ajax_request();
		},
	});
}

function load_rahvar_form(){
	//jQuery.ajax({
	//  type: "post",
	//  url:"http://estelam.rahvar120.ir/includes/services.jsp?serviceid=47",
	//  success:function(data){
	//   jQuery("#sr_ajax_target2").html(data);
	//  }
	//  
	//});
	sr_during_ajax_request();
	jQuery.ajax({
		type: "POST",
		url: pefix_handel.name_1,
		data: {
			action: 'estelam_rahvar_ajax',
			'ajax_type': 'load_rahvar_form',
		},
		error: function(request, status, error) {
			alert("خطا");
		},
		success: function(msg) {
			//jQuery('#sr_ajax_target').html(msg);
			jQuery('#rahvar_page').html(msg);
		},
		complete: function() {
			sr_complete_ajax_request();
		},
	});
}

function render_captcha() {
    var advformid = jQuery('#rahvar_page #advformid').html();
    if (true) {//if (advformid) {
        var cptchid_src = jQuery("#rahvar_page #ch_capt").attr("onclick");
        var cptchid_src_string = jQuery("#rahvar_page #ch_capt").attr("onclick");
		jQuery("#rahvar_page a#rahvar-btn").trigger('click');
        //var string_one = cptchid_src_string.split(";");
        //var string_two = string_one[1].split("'");
        //var src_captcha_img = string_two[3];
       // jQuery(".wizard-container #capimg").attr("src", "http://estelam.rahvar120.ir" + src_captcha_img + Math.random());
       // jQuery(".wizard-container #ch_capt").attr("onclick", "http://estelam.rahvar120.ir/" + cptchid_src);
    } else {
		//alert("فرم راهور در المنت مورد نظر موجود نیست");
        jQuery('#capimg').hide();
        jQuery('#step-3 .form-group').hide();
        jQuery(".message_box_img").html('<div class="alert alert-danger" role="alert">فیلتر شکن خود را خاموش کنید و دکمه استعلام مجدد را بزنید کد 1</div><div role="alert" id="reload" class="alert alert-info" style="width: 200px;margin: auto;"><strong id="jam">استعلام مجدد</strong></div>');
    }
}





function start_garb_captcha() {
	jQuery('.message_box_rahvar').html('<div class="load_rahvar"><div class="lds-ripple"><div></div><div></div></div><div  style="direction:rtl;" class="text_loading">لطفا منتظر بمانید ...</div></div>');
	jQuery('form#js-wizard-form').hide();
	//jQuery('.message_box_rahvar').show();
	//jQuery.get("https://api.ipdata.co?api-key=test", function (response) {
		//alert(JSON.stringify(response, null, 4));
		//console.log(response);
		//console.log(response['country_name']);
		//if(response['country_name'] == "Iran"){
			//ip_condition = true;
			
			
			var inputError = jQuery(".setup-content input").hasClass("error");
			if (!inputError) {
				//load_rahvar_form();
				//jQuery("#rahvar_page").load("http://estelam.rahvar120.ir/index.jsp?pageid=2371666&p=1 form#advformid");
				//jQuery("#rahvar_page").empty();
				//jQuery( "#rahvar_page" ).append( jQuery( "#sr_ajax_target form#advformid" ));
				//jQuery("#rahvar_page").load("https://farmooon.com/rahvar120/rahvar form#advformid");
				jQuery('.message_box_rahvar').show();
				var advformid = jQuery('#rahvar_page #advformid');
				if (!advformid) {
					jQuery('.message_box_rahvar').html('<div class="alert alert-danger" role="alert">سامانه راهور در حال حاضر در دسترس نیست</div>');
				} else {
					render_captcha();
					var rc = jQuery('#rahvar_page input[name="rc"]').val();
					var cptchid = jQuery('#rahvar_page #cptchid').val();
					jQuery('.wizard-container input[name="rc"]').val(rc);
					jQuery('.wizard-container #cptchid').val(cptchid);
					jQuery('#captcha-img').show();
					//var capimg_valid = jQuery('#rahvar_page #capimg');
					//var advformid = jQuery('#rahvar_page #advformid');
					//var proxy = jQuery('#rahvar_page');
					jQuery('.message_box_rahvar').hide();
					jQuery('form#js-wizard-form').show();
					jQuery('form#js-wizard-form div#captcha-img img#capimg').error(function() {
						jQuery('.message_box_img').html('<div class="alert alert-danger" role="alert">فیلتر شکن خود را خاموش کنید و دکمه استعلام مجدد را بزنید کد 2</div><div role="alert" id="reload" class="alert alert-info" style="width: 200px;margin: auto;"><strong id="jam">استعلام مجدد</strong></div>');
						jQuery('#box_img_captcha').hide();
						jQuery('#wrap-rahvar-btn').hide();
					});
					
					
					
				}
				
				//if(jQuery('form#js-wizard-form div#captcha-img img#capimg').complete){
				//	  alert("loded");
				//   }else{
				//	  alert("not loded");
				//   }
				/*
				jQuery.ajax({
					type: "GET",
					//url: "https://farmooon.com/rahvar120/rahvar",
					url: pefix_handel.name_1,
					data: {
						action: 'estelam_rahvar_ajax',
						'ajax_type': 'load_rahvar_form',
					},
					timeout: 10000,
					async: true,
					beforeSend: function() {
						jQuery('#captcha-img').hide();
						jQuery('.message_box_rahvar').html('<div class="load_rahvar"><div class="lds-ripple"><div></div><div></div></div><div  style="direction:rtl;" class="text_loading">لطفا منتظر بمانید ...</div></div>');
					},
					error: function(request, status, error) {
						jQuery('.message_box_rahvar').html('<div class="alert alert-danger" role="alert">سامانه راهور در حال حاضر در دسترس نیست</div>');
					},
					success: function() {
						
						setTimeout(function() {
							var advformid = jQuery('#rahvar_page #advformid');
							if (!advformid) {
								jQuery('.message_box_rahvar').html('<div class="alert alert-danger" role="alert">سامانه راهور در حال حاضر در دسترس نیست</div>');
							} else {
								render_captcha();
								var rc = jQuery('#rahvar_page input[name="rc"]').val();
								var cptchid = jQuery('#rahvar_page #cptchid').val();
								jQuery('.wizard-container input[name="rc"]').val(rc);
								jQuery('.wizard-container #cptchid').val(cptchid);
								jQuery('#captcha-img').show();
								var capimg_valid = jQuery('#rahvar_page #capimg');
								var advformid = jQuery('#rahvar_page #advformid');
								var proxy = jQuery('#rahvar_page');
								jQuery('.message_box_rahvar').hide();
								jQuery('form#js-wizard-form').show();
							}
						}, 5000);  
					},
				});
				*/
			}
			
			
			 
			
			
		//}else{
			
			//jQuery('form#js-wizard-form').hide(); 
			//ip_condition = false;
			//jQuery('.message_box_rahvar').html('<div class="alert alert-danger" role="alert">فیلتر شکن خود را خاموش کنید و دکمه استعلام مجدد را بزنید</div><div role="alert" id="reload" class="alert alert-info" style="width: 200px;margin: auto;"><strong id="jam">استعلام مجدد</strong></div>');
			
			
		//}	
		
	//}, "jsonp");
	
	//if(ip_condition == true){
		
	//}
}



function form_submit() {
	var hashtraghami = jQuery('#hashtraghami').val();
	//console.log(hashtraghami);
    jQuery.ajax({
        type: "POST",
		url: pefix_handel.name_1,
		data: {
			action: 'estelam_rahvar_ajax',
			'ajax_type': 'submit_rahvar_form',
			'hashtraghami' : hashtraghami,
		},
        beforeSend: function() {
            jQuery('.message_box').html('<div class="result_rahvar"><div class="lds-ripple"><div></div><div></div></div><div class="text_loading">درحال اتصال به سامانه راهور</div></div>');
        }, 
		error: function(request, status, error) {
			jQuery(".message_box").html('<div class="alert alert-danger" role="alert">خطا از api</div>');
			console.log(request);
			console.log(status);
			console.log(error);
		},
        success: function(data) {
			//console.log(data);
			//jQuery(".message_box").html(data);//نمایش تستی کل پاسخ ای جکس در جعبه پیام 
			//jQuery('#result_table').show();//نمایش تستی دیوی که کل پاسخ ای جکس  داخلش موجوده
			
            jQuery('#result_table').html(data);
            //jQuery("#result_table style").remove();
            //jQuery("#result_table link").remove();
			var t1 = jQuery('#result_table table').html();
			if (!t1) {
				var rahvar_api_status_description = jQuery("#rahvar_api_status_description").text();
				jQuery(".message_box").html('');
				jQuery(".message_box").append('<div class="alert alert-info" role="alert">'+ rahvar_api_status_description +'</div>');
				jQuery(".message_box").append('<div role="alert" id="reload" class="alert alert-info" style="width: 200px;margin: auto;"><strong id="jam">استعلام مجدد</strong></div>');

			} else {
				jQuery(".message_box").html(''); 
				
				//jQuery(".message_box").append('');
				//jQuery(".message_box").append('');
				
				jQuery('#t1 > tbody').each(function() {
					var t1 = jQuery('#t1 >tbody').html();
					jQuery('#table_final >tbody').append(t1);
					jQuery('#table_final').show();
					jQuery("#table_final .odd").remove();
				});
				var total = jQuery('#result_table #t1 tbody tr').length;
				//jQuery(".message_box").append('');
				var total_price = 0;
				var price = ' ';
				jQuery('#table_final tbody tr  td:nth-child(4)').each(function() {
					price = parseInt(jQuery(this).text());
					total_price += price;
				});
				var table = jQuery('#table_final').DataTable( {
					"lengthChange": true,
					dom: 'Blfrtip',
					 buttons: [
						  'copy', 'excel', 'pdf', 'print'
					  ],
					"searching": false,
					"paging": true,
					"pageLength": 20,
					"ordering": false,
					"columnDefs": [
						{'max-width': '40%', 'targets': 0},
						//{
						//	"targets": [ 9 ],
						//	"visible": false,
						//	"searchable": false
						//},
						//{  
						//	"targets": [ 8 ],
						//	"visible": false,
						//	"searchable": false
						//},
						{ "responsivePriority": 1, "targets": 0 },
						{ "responsivePriority": 2, "targets": 3 },
						{ "responsivePriority": 3, "targets": 4 },
					],
					"lengthMenu": [ 10, 20, 30, 50, 100 ],
					"responsive": true,
					select: true,
					"language": {
						"lengthMenu": "نمایش _MENU_ رکورد",
						"zeroRecords": "رکوردی پیدا نشد",
						"info": "نمایش صفحه _PAGE_ از _PAGES_",
						"infoEmpty": "هیچ رکوردی ثبت نشده است",
						"infoFiltered": "(filtered from _MAX_ total records)",
						"search": "",
						"print": "چاپ",
						"paginate": {
							"first": "First",
							"last": "Last",
							"next": "بعدی",
							"previous": "قبلی"
						},

					}
				} );
				table.on('page.dt', function() {
				  jQuery('html, body').animate({
					scrollTop: jQuery(".dataTables_wrapper").offset().top
				   }, 'slow');
				});
					 
					
				//function get_data_rahvar() {
					
					//jQuery(".message_box").append('');
					var pelak_str = jQuery('#result_table tbody tr:nth-child(1) td:nth-child(10)').text();
					var p1 = pelak_str.substr(0, 6);//ایران
					var p2 = pelak_str.substr(7, 2);//16
					var p3 = pelak_str.substr(14, 3);//70
					var p4 = pelak_str.substr(17, 1);//ط
					var p5 = pelak_str.substr(18, 2);//593
					var p6 = pelak_str.substr(17, 3);//ط593
					
					p2.toPersinaDigit();
					p3.toPersinaDigit();
					p5.toPersinaDigit();
					
					//alert(persiaNumber(p2));
					jQuery(".message_box").append(`
					
													<div class="alert alert-success" id="list_takhalofaat" role="alert">لیست خلافی شما</div>
											<div class="row">
												<div class="col-lg-4 base_main_first">
													<div class="takbox">
														<div class="alboxr">
															<div role="alert" class="alert alert-success">
																<strong>تعداد  تخلفات</strong>
															</div>
														</div>
														<div class="alboxl">
															<div role="alert" class="alert alert-info">
																<strong id="jam">` + total + `</strong>
															</div>
														</div>
													</div>
													<div class="takbox">
														<div class="alboxr">
															<div role="alert" class="alert alert-success">
																<strong>جمع کل </strong>
															</div>
														</div>
														<div class="alboxl">
															<div role="alert" class="alert alert-info">
																<strong id="SpnSumPrices">` + addCommas(total_price) + `  ریال </strong>
															</div>
														</div>
													</div>
												</div>
												<div class="col-lg-4 base_main_first"> 
													<div class="plbox">
														<div id="p3" class="irch">` + p2.toPersinaDigit() + `</div>
														<div id="p4" class="plch">` + p3.toPersinaDigit() + `</div>
														<div id="p5" class="plch1">` + p4 + p5.toPersinaDigit() +`</div>
													</div>
												</div>
												<div class="col-lg-4 base_main_first" style="">
													<div class="takbox">
														<div class="alboxr">
															<div role="alert" class="alert alert-success" id="btnPrint" >
																<strong>چاپ</strong>
															</div>
														</div>
														<div class="alboxl">
															<div role="alert" id="reload" class="alert alert-info">
																<strong id="jam">استعلام مجدد</strong>
															</div>
														</div>
													</div>
												</div>
											</div>
					`);
					
				//} 
				//setTimeout(get_data_rahvar, 3000);
				//get_data_rahvar();
				
			} 
           
			
        }
    });
}


jQuery(document).on('click', '#reload', function(){
    location.reload();
});
jQuery(document).on('click', '#btnPrint', function(){
    //jQuery('table#table_final').printThis();
	jQuery('button.dt-button.buttons-print').trigger('click')
	
});

jQuery(document).ready( function () {
    //jQuery('#table_final').DataTable();
} );






